@@ -34,10 +34,9 @@ import Data.Tree
 import Data.Maybe
 import Data.XCB.FromXML
 import Data.XCB.Types as X
+import Data.XCB.Python.AST (Expr(..), Op(..), Statement(..), Suite, prettyText)
 import Data.XCB.Python.PyHelpers
 
-import Language.Python.Common as P
-
 import System.FilePath
 import System.FilePath.Glob
 
@@ -55,15 +54,15 @@ data TypeInfo =
 type TypeInfoMap = M.Map X.Type TypeInfo
 
 data BindingPart =
-  Request (Statement ()) (Suite ()) |
-  Declaration (Suite ()) |
+  Request Statement Suite |
+  Declaration Suite |
   Noop
   deriving (Show)
 
-collectBindings :: [BindingPart] -> (Suite (), Suite ())
+collectBindings :: [BindingPart] -> (Suite, Suite)
 collectBindings = foldr collectR ([], [])
   where
-    collectR :: BindingPart -> (Suite (), Suite ()) -> (Suite (), Suite ())
+    collectR :: BindingPart -> (Suite, Suite) -> (Suite, Suite)
     collectR (Request def decl) (defs, decls) = (def : defs, decl ++ decls)
     collectR (Declaration decl) (defs, decls) = (defs, decl ++ decls)
     collectR Noop x = x
@@ -73,32 +72,33 @@ parseXHeaders fp = do
   files <- namesMatching $ fp </> "*.xml"
   fromFiles files
 
-renderPy :: Suite () -> String
+renderPy :: Suite -> String
 renderPy s = ((intercalate "\n") $ map prettyText s) ++ "\n"
 
 -- | Generate the code for a set of X headers. Note that the code is generated
 -- in dependency order, NOT in the order you pass them in. Thus, you get a
 -- string (a suggested filename) along with the python code for that XHeader
 -- back.
-xform :: [XHeader] -> [(String, Suite ())]
+xform :: [XHeader] -> [(String, Suite)]
 xform = map buildPython . dependencyOrder
   where
-    buildPython :: Tree XHeader -> (String, Suite ())
+    buildPython :: Tree XHeader -> (String, Suite)
     buildPython forest =
       let forest' = (mapM processXHeader $ postOrder forest)
           results = evalState forest' baseTypeInfo
       in last results
     processXHeader :: XHeader
-                   -> State TypeInfoMap (String, Suite ())
+                   -> State TypeInfoMap (String, Suite)
     processXHeader header = do
-      let imports = [mkImport "xcffib", mkImport "struct", mkImport "io"]
+      let imports = [Import "xcffib", Import "struct", Import "io"]
           version = mkVersion header
           key = maybeToList $ mkKey header
           globals = [mkDict "_events", mkDict "_errors"]
           name = xheader_header header
           add = [mkAddExt header]
-      parts <- mapM (processXDecl name) $ xheader_decls header
-      let (requests, decls) = collectBindings parts
+      partsList <- mapM (processXDecl name) $ xheader_decls header
+      let parts = concat partsList
+          (requests, decls) = collectBindings parts
           ext = if length requests > 0
                 then [mkClass (name ++ "Extension") "xcffib.Extension" requests]
                 else []
@@ -120,20 +120,20 @@ xform = map buildPython . dependencyOrder
     postOrder (Node e cs) = (concat $ map postOrder cs) ++ [e]
 
 
-mkAddExt :: XHeader -> Statement ()
+mkAddExt :: XHeader -> Statement
 mkAddExt (xheader_header -> "xproto") =
-  flip StmtExpr () $ mkCall "xcffib._add_core" [ mkName "xprotoExtension"
-                                               , mkName "Setup"
-                                               , mkName "_events"
-                                               , mkName "_errors"
-                                               ]
+  StmtExpr $ mkCall "xcffib._add_core" [ mkName "xprotoExtension"
+                                       , mkName "Setup"
+                                       , mkName "_events"
+                                       , mkName "_errors"
+                                       ]
 mkAddExt header =
   let name = xheader_header header
-  in flip StmtExpr () $ mkCall "xcffib._add_ext" [ mkName "key"
-                                                 , mkName (name ++ "Extension")
-                                                 , mkName "_events"
-                                                 , mkName "_errors"
-                                                 ]
+  in StmtExpr $ mkCall "xcffib._add_ext" [ mkName "key"
+                                         , mkName (name ++ "Extension")
+                                         , mkName "_events"
+                                         , mkName "_errors"
+                                         ]
 
 -- | Information on basic X types.
 baseTypeInfo :: TypeInfoMap
@@ -189,26 +189,26 @@ calcsize str = sum [fromMaybe 1 i * getSize c | (i, c) <- parseMembers str]
 
     lang = many $ (,) <$> optional decimal <*> (satisfy $ inClass $ M.keys sizeM)
 
-xBinopToPyOp :: X.Binop -> P.Op ()
-xBinopToPyOp X.Add = P.Plus ()
-xBinopToPyOp X.Sub = P.Minus ()
-xBinopToPyOp X.Mult = P.Multiply ()
-xBinopToPyOp X.Div = P.FloorDivide ()
-xBinopToPyOp X.And = P.BinaryAnd ()
-xBinopToPyOp X.RShift = P.ShiftRight ()
+xBinopToPyOp :: X.Binop -> Op
+xBinopToPyOp X.Add = Plus
+xBinopToPyOp X.Sub = Minus
+xBinopToPyOp X.Mult = Multiply
+xBinopToPyOp X.Div = FloorDivide
+xBinopToPyOp X.And = BinaryAnd
+xBinopToPyOp X.RShift = ShiftRight
 
-xUnopToPyOp :: X.Unop -> P.Op ()
-xUnopToPyOp X.Complement = P.Invert ()
+xUnopToPyOp :: X.Unop -> Op
+xUnopToPyOp X.Complement = Invert
 
-xExpressionToNestedPyExpr :: (String -> String) -> XExpression -> Expr ()
+xExpressionToNestedPyExpr :: (String -> String) -> XExpression -> Expr
 xExpressionToNestedPyExpr acc (Op o e1 e2) =
-  Paren (xExpressionToPyExpr acc (Op o e1 e2)) ()
+  Paren (xExpressionToPyExpr acc (Op o e1 e2))
 xExpressionToNestedPyExpr acc xexpr =
   xExpressionToPyExpr acc xexpr
 
-xExpressionToPyExpr :: (String -> String) -> XExpression -> Expr ()
-xExpressionToPyExpr _ (Value i) = mkInt i
-xExpressionToPyExpr _ (Bit i) = BinaryOp (ShiftLeft ()) (mkInt 1) (mkInt i) ()
+xExpressionToPyExpr :: (String -> String) -> XExpression -> Expr
+xExpressionToPyExpr _ (Value i) = Int i
+xExpressionToPyExpr _ (Bit i) = BinaryOp ShiftLeft (Int 1) (Int i)
 xExpressionToPyExpr acc (FieldRef n) = mkName $ acc n
 xExpressionToPyExpr _ (EnumRef (UnQualType enum) n) = mkName $ enum ++ "." ++ n
 -- Currently xcb only uses unqualified types, not sure how qualtype should behave
@@ -221,11 +221,11 @@ xExpressionToPyExpr acc (Op o e1 e2) =
   let o' = xBinopToPyOp o
       e1' = xExpressionToNestedPyExpr acc e1
       e2' = xExpressionToNestedPyExpr acc e2
-  in BinaryOp o' e1' e2' ()
+  in BinaryOp o' e1' e2'
 xExpressionToPyExpr acc (Unop o e) =
   let o' = xUnopToPyOp o
       e' = xExpressionToNestedPyExpr acc e
-  in Paren (UnaryOp o' e' ()) ()
+  in Paren (UnaryOp o' e')
 xExpressionToPyExpr acc (ParamRef n) =
     if n == "num_axes"
     then mkName $ acc n
@@ -251,13 +251,13 @@ getConst (Unop o e) = do
 getConst (PopCount e) = fmap popCount $ getConst e
 getConst _ = Nothing
 
-xEnumElemsToPyEnum :: (String -> String) -> [XEnumElem] -> [(String, Expr ())]
+xEnumElemsToPyEnum :: (String -> String) -> [XEnumElem] -> [(String, Expr)]
 xEnumElemsToPyEnum accessor membs = reverse $ conv membs [] [0..]
   where
     exprConv = xExpressionToPyExpr accessor
-    conv :: [XEnumElem] -> [(String, Expr ())] -> [Int] -> [(String, Expr ())]
+    conv :: [XEnumElem] -> [(String, Expr)] -> [Int] -> [(String, Expr)]
     conv ((EnumElem name expr) : els) acc is =
-      let expr' = fromMaybe (mkInt (head is)) $ fmap exprConv expr
+      let expr' = fromMaybe (Int (head is)) $ fmap exprConv expr
           is' = dropWhile (<= (fromIntegral (int_value expr'))) is
           acc' = (name, expr') : acc
       in conv els acc' is'
@@ -283,13 +283,13 @@ mkPad :: Int -> String
 mkPad 1 = "x"
 mkPad i = (show i) ++ "x"
 
-structElemToPyUnpack :: Expr ()
+structElemToPyUnpack :: Expr
                      -> String
                      -> TypeInfoMap
                      -> GenStructElem Type
                      -> Either (Maybe String, String)
-                               (String, Either (Expr (), Expr ())
-                                               ([(Expr (), [GenStructElem Type])]), Maybe Int)
+                               (String, Either (Expr, Expr)
+                                               ([(Expr, [GenStructElem Type])]), Maybe Int)
 structElemToPyUnpack _ _ _ (Pad PadBytes i) = Left (Nothing, mkPad i)
 structElemToPyUnpack _ _ _ (Pad PadAlignment _) = Left (Nothing, "")
 
@@ -305,23 +305,27 @@ structElemToPyUnpack _ _ _ (Switch name expr _ bitcases) =
       switch = map (mkSwitch cmp) bitcases
   in Right (name, Right switch, Nothing)
     where
-      mkSwitch :: Expr ()
+      mkSwitch :: Expr
                -> BitCase
-               -> (Expr (), [GenStructElem Type])
+               -> (Expr, [GenStructElem Type])
       mkSwitch cmp (BitCase Nothing bcCmp _ elems) =
-        let cmpVal = xExpressionToPyExpr id bcCmp
-            equality = BinaryOp (P.BinaryAnd ()) cmp cmpVal ()
+        -- note: head here and below is a hack; i am not exactly sure the
+        -- semantics of the multi-expression BitCase, since it's "fake" and
+        -- "encoded only once" see b3b5e029e7ad ("XKB: Fix GetKbdByName") for
+        -- details. needs some wiresniffing to investigate.
+        let cmpVal = xExpressionToPyExpr id (head bcCmp)
+            equality = BinaryOp BinaryAnd cmp cmpVal
         in (equality, elems)
 
       mkSwitch cmp (BitCase (Just _) bcCmp _ elems) =
-        let cmpVal = xExpressionToPyExpr id bcCmp
-            equality = BinaryOp (P.Equality ()) cmp cmpVal ()
+        let cmpVal = xExpressionToPyExpr id (head bcCmp)
+            equality = BinaryOp Equality cmp cmpVal
         in (equality, elems)
 
 -- The enum field is mostly for user information, so we ignore it.
 structElemToPyUnpack unpacker ext m (X.List n typ len _) =
   let attr = ((++) "self.")
-      len' = fromMaybe pyNone $ fmap (xExpressionToPyExpr attr) len
+      len' = fromMaybe None $ fmap (xExpressionToPyExpr attr) len
       cons = case m M.! typ of
                BaseType c -> mkStr c
                CompositeType tExt c | ext /= tExt -> mkName $ tExt ++ "." ++ c
@@ -355,8 +359,8 @@ structElemToPyPack :: String
                    -> TypeInfoMap
                    -> (String -> String)
                    -> GenStructElem Type
-                   -> Either (Maybe String, String) [(String, Either (Maybe (Expr ()))
-                                                                     [(Expr (), [GenStructElem Type])]
+                   -> Either (Maybe String, String) [(String, Either (Maybe (Expr))
+                                                                     [(Expr, [GenStructElem Type])]
                                                     )]
 structElemToPyPack _ _ _ (Pad _ i) = Left (Nothing, mkPad i)
 -- TODO: implement these?
@@ -369,25 +373,26 @@ structElemToPyPack _ _ accessor (Switch n expr _ bitcases) =
       elems = map (mkSwitch cmp) bitcases
   in Right $ [(name, Right elems)]
     where
-      mkSwitch :: Expr ()
+      mkSwitch :: Expr
                -> BitCase
-               -> (Expr (), [GenStructElem Type])
+               -> (Expr, [GenStructElem Type])
       mkSwitch cmp (BitCase _ bcCmp _ elems') =
-        let cmpVal = xExpressionToPyExpr accessor bcCmp
-            equality = BinaryOp (P.BinaryAnd ()) cmp cmpVal ()
+        -- see comment above about head for BitCase
+        let cmpVal = xExpressionToPyExpr accessor (head bcCmp)
+            equality = BinaryOp BinaryAnd cmp cmpVal
         in (equality, elems')
 structElemToPyPack ext m accessor (SField n typ _ _) =
   let name = accessor n
   in case m M.! typ of
        BaseType c -> Left (Just name, c)
        CompositeType tExt typNam ->
-         let cond = mkCall "hasattr" [mkArg name, ArgExpr (mkStr "pack") ()]
-             trueB = mkCall (name ++ ".pack") noArgs
+         let cond = mkCall "hasattr" [mkName name, (mkStr "pack")]
+             trueB = mkCall (name ++ ".pack") []
              typNam' = if ext == tExt then typNam else tExt ++ "." ++ typNam
-             synthetic = mkCall (typNam' ++ ".synthetic") [mkArg ("*" ++ name)]
-             falseB = mkCall (mkDot synthetic "pack") noArgs
+             synthetic = mkCall (typNam' ++ ".synthetic") [mkName ("*" ++ name)]
+             falseB = mkCall (mkDot synthetic "pack") []
          in Right $ [(name
-                    , Left (Just (CondExpr trueB cond falseB ()))
+                    , Left (Just (CondExpr trueB cond falseB))
                     )]
 -- TODO: assert values are in enum?
 structElemToPyPack ext m accessor (X.List n typ expr _) =
@@ -421,7 +426,7 @@ structElemToPyPack _ m accessor (ExprField name typ expr) =
                                                                 ]))
                              )]
        CompositeType _ _ -> Right $ [(name'
-                                    , Left (Just (mkCall (mkDot e "pack") noArgs))
+                                    , Left (Just (mkCall (mkDot e "pack") []))
                                     )]
 
 -- As near as I can tell here the padding param is unused.
@@ -436,8 +441,8 @@ structElemToPyPack _ m accessor (ValueParam typ mask _ list) =
     CompositeType _ _ -> error (
       "ValueParams other than CARD{16,32} not allowed.")
 
-buf :: Suite ()
-buf = [mkAssign "buf" (mkCall "io.BytesIO" noArgs)]
+buf :: Suite
+buf = [mkAssign "buf" (mkCall "io.BytesIO" [])]
 
 mkPackStmts :: String
             -> String
@@ -445,7 +450,7 @@ mkPackStmts :: String
             -> (String -> String)
             -> String
             -> [GenStructElem Type]
-            -> ([String], Suite ())
+            -> ([String], Suite)
 mkPackStmts ext name m accessor prefix membs =
   let packF = structElemToPyPack ext m accessor
       (toPack, stmts) = span EC.isLeft $ map packF membs
@@ -471,30 +476,30 @@ mkPackStmts ext name m accessor prefix membs =
       packStr = addStructData prefix $ intercalate "" keys
       write = mkCall "buf.write" [mkCall "struct.pack"
                                          (mkStr ('=' : packStr) : (map mkName args))]
-      writeStmt = if length packStr > 0 then [StmtExpr write ()] else []
+      writeStmt = if length packStr > 0 then [StmtExpr write] else []
   in (args ++ listNames', writeStmt ++ listWrites)
     where
       mkWrites :: String
-               -> Either (Maybe (Expr ()))
-                         [(Expr (), [GenStructElem Type])]
-               -> Suite ()
+               -> Either (Maybe (Expr))
+                         [(Expr, [GenStructElem Type])]
+               -> Suite
       mkWrites _ (Left Nothing) = []
       mkWrites _ (Left (Just expr)) = [mkListWrite expr]
       mkWrites valueList (Right condList) =
         let (conds, exprs) = unzip condList
             (names, stmts) = unzip $ map (mkPackStmts ext name m accessor "") exprs
-        in map (\(x, y, z) -> Conditional [(x, map (mkPop valueList) y ++ z)] [] ()) $ zip3 conds names stmts
+        in map (\(x, y, z) -> Conditional x (map (mkPop valueList) y ++ z) []) $ zip3 conds names stmts
 
-      mkListWrite :: Expr ()
-                  -> Statement ()
-      mkListWrite expr' = flip StmtExpr () . mkCall "buf.write" $ (: []) expr'
+      mkListWrite :: Expr
+                  -> Statement
+      mkListWrite expr' = StmtExpr . mkCall "buf.write" $ (: []) expr'
 
       mkPop :: String
             -> String
-            -> Statement ()
+            -> Statement
       mkPop toPop n =
-        let pop = mkCall (mkDot toPop "pop") [mkInt 0]
-        in if null n then StmtExpr pop () else mkAssign n pop
+        let pop = mkCall (mkDot toPop "pop") [Int 0]
+        in if null n then StmtExpr pop else mkAssign n pop
 
       mkBasePack (Nothing, "") = []
       mkBasePack (n, c) =
@@ -507,28 +512,29 @@ mkPackMethod :: String
              -> Maybe (String, Int)
              -> [GenStructElem Type]
              -> Maybe Int
-             -> Statement ()
+             -> Statement
 mkPackMethod ext name m prefixAndOp structElems minLen =
   let accessor = ((++) "self.")
       (prefix, op) = case prefixAndOp of
                         Just ('x' : rest, i) ->
-                          let packOpcode = mkCall "struct.pack" [mkStr "=B", mkInt i]
+                          let packOpcode = mkCall "struct.pack" [mkStr "=B", Int i]
                               write = mkCall "buf.write" [packOpcode]
-                          in (rest, [StmtExpr write ()])
+                          in (rest, [StmtExpr write])
                         Just (rest, _) -> error ("internal API error: " ++ show rest)
                         Nothing -> ("", [])
       (_, packStmts) = mkPackStmts ext name m accessor prefix structElems
       extend = concat $ do
         len <- maybeToList minLen
         let bufLen = mkName "buf_len"
-            bufLenAssign = mkAssign bufLen $ mkCall "len" [mkCall "buf.getvalue" noArgs]
-            test = (BinaryOp (LessThan ()) bufLen (mkInt len)) ()
-            bufWriteLen = Paren (BinaryOp (Minus ()) (mkInt 32) bufLen ()) ()
-            extra = mkCall "struct.pack" [repeatStr "x" bufWriteLen]
-            writeExtra = [StmtExpr (mkCall "buf.write" [extra]) ()]
+            bufLenAssign = mkAssign bufLen $ mkCall "len" [mkCall "buf.getvalue" []]
+            test = (BinaryOp LessThan bufLen (Int len))
+            bufWriteLen = Paren (BinaryOp Minus (Int 32) bufLen)
+            extraPackFmt = Paren (BinaryOp Modulo (mkStr "%dx") bufWriteLen)
+            extra = mkCall "struct.pack" [extraPackFmt]
+            writeExtra = [StmtExpr (mkCall "buf.write" [extra])]
         return $ [bufLenAssign, mkIf test writeExtra]
-      ret = [mkReturn $ mkCall "buf.getvalue" noArgs]
-  in mkMethod "pack" (mkParams ["self"]) $ buf ++ op ++ packStmts ++ extend ++ ret
+      ret = [mkReturn $ mkCall "buf.getvalue" []]
+  in mkMethod "pack" ["self"] $ buf ++ op ++ packStmts ++ extend ++ ret
 
 data StructUnpackState = StructUnpackState {
   -- | stNeedsPad is whether or not a type_pad() is needed. As near
@@ -552,14 +558,14 @@ mkStructStyleUnpack :: String
                     -> String
                     -> TypeInfoMap
                     -> [GenStructElem Type]
-                    -> (Suite (), Maybe Int)
+                    -> (Suite, Maybe Int)
 mkStructStyleUnpack prefix ext m membs =
   let unpacked = map (structElemToPyUnpack (mkName "unpacker") ext m) membs
       initial = StructUnpackState False [] prefix
       (_, unpackStmts, size) = evalState (mkUnpackStmts unpacked) initial
       base = [mkAssign "base" $ mkName "unpacker.offset"]
       bufsize =
-        let rhs = BinaryOp (Minus ()) (mkName "unpacker.offset") (mkName "base") ()
+        let rhs = BinaryOp Minus (mkName "unpacker.offset") (mkName "base")
         in [mkAssign (mkAttr "bufsize") rhs]
       statements = base ++ unpackStmts ++ bufsize
   in (statements, size)
@@ -568,9 +574,9 @@ mkStructStyleUnpack prefix ext m membs =
       -- Apparently you only type_pad before unpacking Structs or Lists, never
       -- base types.
       mkUnpackStmts :: [Either (Maybe String, String)
-                               (String, Either (Expr (), Expr ())
-                                               ([(Expr (), [GenStructElem Type])]), Maybe Int)]
-                    -> State StructUnpackState ([String], Suite (), Maybe Int)
+                               (String, Either (Expr, Expr)
+                                               ([(Expr, [GenStructElem Type])]), Maybe Int)]
+                    -> State StructUnpackState ([String], Suite, Maybe Int)
 
       mkUnpackStmts [] = flushAcc
 
@@ -601,11 +607,11 @@ mkStructStyleUnpack prefix ext m membs =
                )
           where
             mkUnpackListOrSwitch :: String
-                                 -> Either (Expr (), Expr ())
-                                           ([(Expr (), [GenStructElem Type])])
+                                 -> Either (Expr, Expr)
+                                           ([(Expr, [GenStructElem Type])])
                                  -> Bool
                                  -> StructUnpackState
-                                 -> Suite ()
+                                 -> Suite
             mkUnpackListOrSwitch name' (Left (list, cons)) needsPad _ =
               let pad = if needsPad
                         then [typePad cons]
@@ -614,17 +620,17 @@ mkStructStyleUnpack prefix ext m membs =
             mkUnpackListOrSwitch _ (Right switchList) _ st' =
               let (conds, elems) = unzip switchList
                   stmts = map (mkUnpackSwitchElems st') elems
-              in map (\x -> Conditional [x] [] ()) $ zip conds stmts
+              in map (\(cond,body) -> Conditional cond body []) $ zip conds stmts
 
             mkUnpackSwitchElems :: StructUnpackState
                                 -> [GenStructElem Type]
-                                -> Suite ()
+                                -> Suite
             mkUnpackSwitchElems st' elems' =
               let unpacked' = map (structElemToPyUnpack (mkName "unpacker") ext m) elems'
                   (_, stmts', _) = evalState (mkUnpackStmts unpacked') st'
               in stmts'
 
-      flushAcc :: State StructUnpackState ([String], Suite (), Maybe Int)
+      flushAcc :: State StructUnpackState ([String], Suite, Maybe Int)
       flushAcc = do
         StructUnpackState needsPad args keys <- get
         let size = calcsize keys
@@ -632,7 +638,7 @@ mkStructStyleUnpack prefix ext m membs =
         put $ StructUnpackState needsPad [] ""
         return (args, assign, Just size)
 
-      typePad e = StmtExpr (mkCall "unpacker.pad" [e]) ()
+      typePad e = StmtExpr (mkCall "unpacker.pad" [e])
 
 -- | Given a (qualified) type name and a target type, generate a TypeInfoMap
 -- updater.
@@ -643,16 +649,15 @@ mkModify ext name ti m =
                       ]
   in M.union m m'
 
-mkSyntheticMethod :: [GenStructElem Type] -> [Statement ()]
+mkSyntheticMethod :: [GenStructElem Type] -> [Statement]
 mkSyntheticMethod membs = do
   let names = catMaybes $ map getName membs
-      args = mkParams $ "cls" : names
+      args = "cls" : names
       self = mkAssign "self" $ mkCall (mkDot "cls" "__new__") [mkName "cls"]
       body = map assign names
       ret = mkReturn $ mkName "self"
-      synthetic = mkMethod "synthetic" args $ (self : body) ++ [ret]
-      classmethod = Decorator [ident "classmethod"] noArgs ()
-  if null names then [] else [Decorated [classmethod] synthetic ()]
+      synthetic = Decorated "classmethod" "synthetic" args $ (self : body) ++ [ret]
+  if null names then [] else [synthetic]
     where
       getName :: GenStructElem Type -> Maybe String
       getName (Pad _ _) = Nothing
@@ -665,23 +670,23 @@ mkSyntheticMethod membs = do
       getName (Fd n) = Just n
       getName (Length _ _) = Nothing
 
-      assign :: String -> Statement ()
+      assign :: String -> Statement
       assign n = mkAssign (mkDot "self" n) $ mkName n
 
 processXDecl :: String
              -> XDecl
-             -> State TypeInfoMap BindingPart
+             -> State TypeInfoMap [BindingPart]
 processXDecl ext (XTypeDef name typ) =
   do modify $ \m -> mkModify ext name (m M.! typ) m
-     return Noop
+     return [Noop]
 processXDecl ext (XidType name) =
   -- http://www.markwitmer.com/guile-xcb/doc/guile-xcb/XIDs.html
   do modify $ mkModify ext name (BaseType "I")
-     return Noop
+     return [Noop]
 processXDecl _ (XImport n) =
-  return $ Declaration [ mkRelImport n]
+  return [Declaration [ mkRelImport n]]
 processXDecl _ (XEnum name membs) =
-  return $ Declaration [mkEnum name $ xEnumElemsToPyEnum id membs]
+  return [Declaration [mkEnum name $ xEnumElemsToPyEnum id membs]]
 processXDecl ext (XStruct n _ membs) = do
   m <- get
   let (statements, len) = mkStructStyleUnpack "" ext m membs
@@ -689,10 +694,10 @@ processXDecl ext (XStruct n _ membs) = do
       synthetic = mkSyntheticMethod membs
       fixedLength = maybeToList $ do
         theLen <- len
-        let rhs = mkInt theLen
+        let rhs = Int theLen
         return $ mkAssign "fixed_size" rhs
   modify $ mkModify ext n (CompositeType ext n)
-  return $ Declaration [mkXClass n "xcffib.Struct" False statements (pack : fixedLength ++ synthetic)]
+  return [Declaration [mkXClass n "xcffib.Struct" False statements (pack : fixedLength ++ synthetic)]]
 processXDecl ext (XEvent name opcode _ xge membs noSequence) = do
   m <- get
   let cname = name ++ "Event"
@@ -703,9 +708,9 @@ processXDecl ext (XEvent name opcode _ xge membs noSequence) = do
       eventsUpd = mkDictUpdate "_events" opcode cname
       isxge = fromMaybe False xge
       -- xgeexp = mkAssign "xge" (if fromMaybe False xge then (mkName "True") else (mkName "False"))
-  return $ Declaration [ mkXClass cname "xcffib.Event" isxge statements (pack : synthetic)
+  return [Declaration [ mkXClass cname "xcffib.Event" isxge statements (pack : synthetic)
                        , eventsUpd
-                       ]
+                       ]]
 processXDecl ext (XError name opcode _ membs) = do
   m <- get
   let cname = name ++ "Error"
@@ -714,10 +719,10 @@ processXDecl ext (XError name opcode _ membs) = do
       (statements, _) = mkStructStyleUnpack prefix ext m membs
       errorsUpd = mkDictUpdate "_errors" opcode cname
       alias = mkAssign ("Bad" ++ name) (mkName cname)
-  return $ Declaration [ mkXClass cname "xcffib.Error" False statements [pack]
+  return [Declaration [ mkXClass cname "xcffib.Error" False statements [pack]
                        , alias
                        , errorsUpd
-                       ]
+                       ]]
 processXDecl ext (XRequest name opcode _ membs reply) = do
   m <- get
   let
@@ -736,50 +741,61 @@ processXDecl ext (XRequest name opcode _ membs reply) = do
         return [theReply, cookie]
 
       hasReply = if length replyDecl > 0
-                 then [ArgExpr (mkName cookieName) ()]
+                 then [mkName cookieName]
                  else []
-      isChecked = pyTruth $ isJust reply
-      argChecked = ArgKeyword (ident "is_checked") (mkName "is_checked") ()
-      checkedParam = Param (ident "is_checked") Nothing (Just isChecked) ()
-      allArgs = (mkParams $ "self" : (filter (not . null) args)) ++ [checkedParam]
-      mkArg' = flip ArgExpr ()
-      ret = mkReturn $ mkCall "self.send_request" ((map mkArg' [ mkInt opcode
-                                                               , mkName "buf"
-                                                               ])
-                                                               ++ hasReply
-                                                               ++ [argChecked])
+      -- another hack for not supporting named parameters
+      -- argChecked = ArgKeyword (ident "is_checked") (mkName "is_checked")
+      argChecked = mkName ("is_checked=is_checked")
+      -- a hack to not have to support separate params/exprs
+      -- checkedParam = Param (ident "is_checked") Nothing (Just isChecked)
+      checkedParam = "is_checked=" ++ (show (isJust reply))
+      allArgs = ("self" : (filter (not . null) args)) ++ [checkedParam]
+      ret = mkReturn $ mkCall "self.send_request" ([ Int opcode
+                                                   , mkName "buf"
+                                                   ]
+                                                   ++ hasReply
+                                                   ++ [argChecked])
       requestBody = buf ++ packStmts ++ [ret]
       request = mkMethod name allArgs requestBody
-  return $ Request request replyDecl
+      baseArgs = ("self" : (filter (not . null) args))
+      checkedMethod = mkMethod (name ++ "Checked") baseArgs
+        [mkReturn $ mkCall ("self." ++ name) (map mkName (tail baseArgs) ++ [mkName "is_checked=True"])]
+      uncheckedMethod = mkMethod (name ++ "Unchecked") baseArgs
+        [mkReturn $ mkCall ("self." ++ name) (map mkName (tail baseArgs) ++ [mkName "is_checked=False"])]
+
+  return [Request request replyDecl, Request checkedMethod [], Request uncheckedMethod []]
 processXDecl ext (XUnion name _ membs) = do
   m <- get
   let unpackF = structElemToPyUnpack unpackerCopy ext m
-      (fields, listInfo) = span EC.isLeft $ map unpackF membs
-      toUnpack = concat $ map (mkUnionUnpack . EC.fromLeft') fields
-      listInfo' = map (either mkBaseUnpack id) listInfo
-      (names, listOrSwitches, _) = unzip3 listInfo'
-      (exprs, _) = unzip $ map EC.fromLeft' listOrSwitches
-      lists = map (uncurry mkAssign) $ zip (map mkAttr names) exprs
-      initMethod = lists ++ toUnpack
+      (_, stmts) = span EC.isLeft $ map unpackF membs
+      -- not exactly correct, same problem as in commit
+      -- 64168007c20e80dd58e2456d8dac74e71d7f6b96 or
+      -- d2d521fd117f2d2698f8d4ef1fd4792a4ef1c088, i.e. we shouldn't partition
+      -- these, we should render them in order. (hilariously, those commits
+      -- mention partitionEithers, which is equivalent to (span EC.isLeft)...
+      initMethodStmts = concat $ map (either mkUnionUnpack mkUnionListUnpack) stmts
       -- Here, we only want to pack the first member of the union, since every
       -- member is the same data and we don't want to repeatedly pack it.
       pack = mkPackMethod ext name m Nothing [head membs] Nothing
-      decl = [mkXClass name "xcffib.Union" False initMethod [pack]]
+      decl = [mkXClass name "xcffib.Union" False initMethodStmts [pack]]
   modify $ mkModify ext name (CompositeType ext name)
-  return $ Declaration decl
+  return [Declaration decl]
   where
-    unpackerCopy = mkCall "unpacker.copy" noArgs
+    unpackerCopy = mkCall "unpacker.copy" []
     mkUnionUnpack :: (Maybe String, String)
-                  -> Suite ()
+                  -> Suite
     mkUnionUnpack (n, typ) =
       mkUnpackFrom unpackerCopy (maybeToList n) typ
 
-    mkBaseUnpack _ = error "xcffib: trailing base types unpack not implemented"
+    mkUnionListUnpack :: (String, Either (Expr, Expr) ([(Expr, [GenStructElem Type])]), Maybe Int) -> Suite
+    mkUnionListUnpack (n, listOrSwitches, _) =
+      let (expr, _) = EC.fromLeft' listOrSwitches
+      in [mkAssign (mkAttr n) expr]
 
 processXDecl ext (XidUnion name _) =
   -- These are always unions of only XIDs.
   do modify $ mkModify ext name (BaseType "I")
-     return Noop
+     return [Noop]
 
 -- EventStruct basically describes a set of possible events that could be
 -- represented by this one member. Slated to land in 1.13, it is only used in
@@ -794,18 +810,18 @@ processXDecl ext (XidUnion name _) =
 -- again.
 processXDecl ext (XEventStruct name _) = do
   modify $ mkModify ext name (CompositeType ext name)
-  return $ Declaration $ [mkXClass name "xcffib.Buffer" False [] []]
+  return [Declaration $ [mkXClass name "xcffib.Buffer" False [] []]]
 
-mkVersion :: XHeader -> Suite ()
+mkVersion :: XHeader -> Suite
 mkVersion header =
   let major = ver "MAJOR_VERSION" (xheader_major_version header)
       minor = ver "MINOR_VERSION" (xheader_minor_version header)
   in major ++ minor
   where
-    ver :: String -> Maybe Int -> Suite ()
-    ver target i = maybeToList $ fmap (\x -> mkAssign target (mkInt x)) i
+    ver :: String -> Maybe Int -> Suite
+    ver target i = maybeToList $ fmap (\x -> mkAssign target (Int x)) i
 
-mkKey :: XHeader -> Maybe (Statement ())
+mkKey :: XHeader -> Maybe (Statement)
 mkKey header = do
   name <- xheader_xname header
   let call = mkCall "xcffib.ExtensionKey" [mkStr name]
