@@ -13,7 +13,7 @@ class RequestError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack("xx2xIHBx")
+        self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack("=xx2xIHBx")
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = io.BytesIO()
