@@ -10,7 +10,7 @@ class KeymapNotifyEvent(xcffib.Event):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Event.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("x")
+        unpacker.unpack("=x")
         self.keys = xcffib.List(unpacker, "B", 31)
         self.bufsize = unpacker.offset - base
     def pack(self):
@@ -19,7 +19,7 @@ class KeymapNotifyEvent(xcffib.Event):
         buf.write(xcffib.pack_list(self.keys, "B"))
         buf_len = len(buf.getvalue())
         if buf_len < 32:
-            buf.write(struct.pack("x" * (32 - buf_len)))
+            buf.write(struct.pack(("%dx" % (32 - buf_len))))
         return buf.getvalue()
     @classmethod
     def synthetic(cls, keys):
