@@ -13,7 +13,7 @@ class COLOR(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.red, self.green, self.blue, self.alpha = unpacker.unpack("HHHH")
+        self.red, self.green, self.blue, self.alpha = unpacker.unpack("=HHHH")
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = io.BytesIO()
@@ -35,7 +35,7 @@ class RECTANGLE(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.x, self.y, self.width, self.height = unpacker.unpack("hhHH")
+        self.x, self.y, self.width, self.height = unpacker.unpack("=hhHH")
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = io.BytesIO()
@@ -57,4 +57,8 @@ class renderExtension(xcffib.Extension):
         buf.write(color.pack() if hasattr(color, "pack") else COLOR.synthetic(*color).pack())
         buf.write(xcffib.pack_list(rects, RECTANGLE))
         return self.send_request(26, buf, is_checked=is_checked)
+    def FillRectanglesChecked(self, op, dst, color, rects_len, rects):
+        return self.FillRectangles(op, dst, color, rects_len, rects, is_checked=True)
+    def FillRectanglesUnchecked(self, op, dst, color, rects_len, rects):
+        return self.FillRectangles(op, dst, color, rects_len, rects, is_checked=False)
 xcffib._add_ext(key, renderExtension, _events, _errors)
