@@ -10,7 +10,7 @@ class INT64(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.hi, self.lo = unpacker.unpack("iI")
+        self.hi, self.lo = unpacker.unpack("=iI")
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = io.BytesIO()
@@ -30,7 +30,7 @@ class GetPropertyReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.num_items, self.format = unpacker.unpack("xx2x4xIB")
+        self.num_items, self.format = unpacker.unpack("=xx2x4xIB")
         if self.format & PropertyFormat._8Bits:
             self.data8 = xcffib.List(unpacker, "B", self.num_items)
         if self.format & PropertyFormat._16Bits:
@@ -47,7 +47,7 @@ class GetPropertyWithPadReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.num_items, self.format = unpacker.unpack("xx2x4xIB")
+        self.num_items, self.format = unpacker.unpack("=xx2x4xIB")
         self.names = xcffib.List(unpacker, "B", self.num_items)
         if self.format & PropertyFormat._8Bits:
             unpacker.pad("B")
@@ -78,8 +78,16 @@ class switchExtension(xcffib.Extension):
             events = items.pop(0)
             buf.write(struct.pack("=I", events))
         return self.send_request(59, buf, GetPropertyCookie, is_checked=is_checked)
+    def GetPropertyChecked(self, value_mask, items):
+        return self.GetProperty(value_mask, items, is_checked=True)
+    def GetPropertyUnchecked(self, value_mask, items):
+        return self.GetProperty(value_mask, items, is_checked=False)
     def GetPropertyWithPad(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(60, buf, GetPropertyWithPadCookie, is_checked=is_checked)
+    def GetPropertyWithPadChecked(self):
+        return self.GetPropertyWithPad(is_checked=True)
+    def GetPropertyWithPadUnchecked(self):
+        return self.GetPropertyWithPad(is_checked=False)
 xcffib._add_ext(key, switchExtension, _events, _errors)
