@@ -10,7 +10,7 @@ class CHARINFO(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.left_side_bearing, self.right_side_bearing, self.character_width, self.ascent, self.descent, self.attributes = unpacker.unpack("hhhhhH")
+        self.left_side_bearing, self.right_side_bearing, self.character_width, self.ascent, self.descent, self.attributes = unpacker.unpack("=hhhhhH")
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = io.BytesIO()
@@ -34,7 +34,7 @@ class FONTPROP(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.name, self.value = unpacker.unpack("II")
+        self.name, self.value = unpacker.unpack("=II")
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = io.BytesIO()
@@ -54,12 +54,12 @@ class ListFontsWithInfoReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.name_len, = unpacker.unpack("xB2x4x")
+        self.name_len, = unpacker.unpack("=xB2x4x")
         self.min_bounds = CHARINFO(unpacker)
-        unpacker.unpack("4x")
+        unpacker.unpack("=4x")
         unpacker.pad(CHARINFO)
         self.max_bounds = CHARINFO(unpacker)
-        self.min_char_or_byte2, self.max_char_or_byte2, self.default_char, self.properties_len, self.draw_direction, self.min_byte1, self.max_byte1, self.all_chars_exist, self.font_ascent, self.font_descent, self.replies_hint = unpacker.unpack("4xHHHHBBBBhhI")
+        self.min_char_or_byte2, self.max_char_or_byte2, self.default_char, self.properties_len, self.draw_direction, self.min_byte1, self.max_byte1, self.all_chars_exist, self.font_ascent, self.font_descent, self.replies_hint = unpacker.unpack("=4xHHHHBBBBhhI")
         unpacker.pad(FONTPROP)
         self.properties = xcffib.List(unpacker, FONTPROP, self.properties_len)
         unpacker.pad("c")
@@ -73,4 +73,8 @@ class type_padExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2xxHH", max_names, pattern_len))
         buf.write(xcffib.pack_list(pattern, "c"))
         return self.send_request(50, buf, ListFontsWithInfoCookie, is_checked=is_checked)
+    def ListFontsWithInfoChecked(self, max_names, pattern_len, pattern):
+        return self.ListFontsWithInfo(max_names, pattern_len, pattern, is_checked=True)
+    def ListFontsWithInfoUnchecked(self, max_names, pattern_len, pattern):
+        return self.ListFontsWithInfo(max_names, pattern_len, pattern, is_checked=False)
 xcffib._add_ext(key, type_padExtension, _events, _errors)
