@@ -39,7 +39,7 @@ c_lib = ffi.dlopen(None)  # Loads the global symbol table (works on Unix/BSD)
 c_free = c_lib.free
 
 __xcb_proto_version__ = "1.17.0"
-__version__ = "1.11.1"
+__version__ = "1.12.0"
 
 X_PROTOCOL = lib.X_PROTOCOL
 X_PROTOCOL_REVISION = lib.X_PROTOCOL_REVISION
@@ -399,19 +399,6 @@ class Extension(object):
 
         return cookie(self.conn, seq, is_checked)
 
-    def __getattr__(self, name):
-        if name.endswith("Checked"):
-            real = name[: -len("Checked")]
-            is_checked = True
-        elif name.endswith("Unchecked"):
-            real = name[: -len("Unchecked")]
-            is_checked = False
-        else:
-            raise AttributeError(name)
-
-        real = getattr(self, real)
-
-        return functools.partial(real, is_checked=is_checked)
 
 
 class List(Protobj):
