@@ -17,7 +17,7 @@ class EnableReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.maximum_request_length,) = unpacker.unpack("xx2x4xI")
+        (self.maximum_request_length,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -31,5 +31,11 @@ class bigreqExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2x"))
         return self.send_request(0, buf, EnableCookie, is_checked=is_checked)
 
+    def EnableChecked(self):
+        return self.Enable(is_checked=True)
+
+    def EnableUnchecked(self):
+        return self.Enable(is_checked=False)
+
 
 xcffib._add_ext(key, bigreqExtension, _events, _errors)
