@@ -116,25 +116,59 @@ class damageExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2xII", client_major_version, client_minor_version))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 
+    def QueryVersionChecked(self, client_major_version, client_minor_version):
+        return self.QueryVersion(
+            client_major_version, client_minor_version, is_checked=True
+        )
+
+    def QueryVersionUnchecked(self, client_major_version, client_minor_version):
+        return self.QueryVersion(
+            client_major_version, client_minor_version, is_checked=False
+        )
+
     def Create(self, damage, drawable, level, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIB3x", damage, drawable, level))
         return self.send_request(1, buf, is_checked=is_checked)
 
+    def CreateChecked(self, damage, drawable, level):
+        return self.Create(damage, drawable, level, is_checked=True)
+
+    def CreateUnchecked(self, damage, drawable, level):
+        return self.Create(damage, drawable, level, is_checked=False)
+
     def Destroy(self, damage, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", damage))
         return self.send_request(2, buf, is_checked=is_checked)
 
+    def DestroyChecked(self, damage):
+        return self.Destroy(damage, is_checked=True)
+
+    def DestroyUnchecked(self, damage):
+        return self.Destroy(damage, is_checked=False)
+
     def Subtract(self, damage, repair, parts, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIII", damage, repair, parts))
         return self.send_request(3, buf, is_checked=is_checked)
 
+    def SubtractChecked(self, damage, repair, parts):
+        return self.Subtract(damage, repair, parts, is_checked=True)
+
+    def SubtractUnchecked(self, damage, repair, parts):
+        return self.Subtract(damage, repair, parts, is_checked=False)
+
     def Add(self, drawable, region, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", drawable, region))
         return self.send_request(4, buf, is_checked=is_checked)
 
+    def AddChecked(self, drawable, region):
+        return self.Add(drawable, region, is_checked=True)
+
+    def AddUnchecked(self, drawable, region):
+        return self.Add(drawable, region, is_checked=False)
+
 
 xcffib._add_ext(key, damageExtension, _events, _errors)
