@@ -384,26 +384,56 @@ class dri2Extension(xcffib.Extension):
         buf.write(struct.pack("=xx2xII", major_version, minor_version))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 
+    def QueryVersionChecked(self, major_version, minor_version):
+        return self.QueryVersion(major_version, minor_version, is_checked=True)
+
+    def QueryVersionUnchecked(self, major_version, minor_version):
+        return self.QueryVersion(major_version, minor_version, is_checked=False)
+
     def Connect(self, window, driver_type, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", window, driver_type))
         return self.send_request(1, buf, ConnectCookie, is_checked=is_checked)
 
+    def ConnectChecked(self, window, driver_type):
+        return self.Connect(window, driver_type, is_checked=True)
+
+    def ConnectUnchecked(self, window, driver_type):
+        return self.Connect(window, driver_type, is_checked=False)
+
     def Authenticate(self, window, magic, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", window, magic))
         return self.send_request(2, buf, AuthenticateCookie, is_checked=is_checked)
 
+    def AuthenticateChecked(self, window, magic):
+        return self.Authenticate(window, magic, is_checked=True)
+
+    def AuthenticateUnchecked(self, window, magic):
+        return self.Authenticate(window, magic, is_checked=False)
+
     def CreateDrawable(self, drawable, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", drawable))
         return self.send_request(3, buf, is_checked=is_checked)
 
+    def CreateDrawableChecked(self, drawable):
+        return self.CreateDrawable(drawable, is_checked=True)
+
+    def CreateDrawableUnchecked(self, drawable):
+        return self.CreateDrawable(drawable, is_checked=False)
+
     def DestroyDrawable(self, drawable, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", drawable))
         return self.send_request(4, buf, is_checked=is_checked)
 
+    def DestroyDrawableChecked(self, drawable):
+        return self.DestroyDrawable(drawable, is_checked=True)
+
+    def DestroyDrawableUnchecked(self, drawable):
+        return self.DestroyDrawable(drawable, is_checked=False)
+
     def GetBuffers(
         self, drawable, count, attachments_len, attachments, is_checked=True
     ):
@@ -412,11 +442,27 @@ class dri2Extension(xcffib.Extension):
         buf.write(xcffib.pack_list(attachments, "I"))
         return self.send_request(5, buf, GetBuffersCookie, is_checked=is_checked)
 
+    def GetBuffersChecked(self, drawable, count, attachments_len, attachments):
+        return self.GetBuffers(
+            drawable, count, attachments_len, attachments, is_checked=True
+        )
+
+    def GetBuffersUnchecked(self, drawable, count, attachments_len, attachments):
+        return self.GetBuffers(
+            drawable, count, attachments_len, attachments, is_checked=False
+        )
+
     def CopyRegion(self, drawable, region, dest, src, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIII", drawable, region, dest, src))
         return self.send_request(6, buf, CopyRegionCookie, is_checked=is_checked)
 
+    def CopyRegionChecked(self, drawable, region, dest, src):
+        return self.CopyRegion(drawable, region, dest, src, is_checked=True)
+
+    def CopyRegionUnchecked(self, drawable, region, dest, src):
+        return self.CopyRegion(drawable, region, dest, src, is_checked=False)
+
     def GetBuffersWithFormat(
         self, drawable, count, attachments_len, attachments, is_checked=True
     ):
@@ -427,6 +473,20 @@ class dri2Extension(xcffib.Extension):
             7, buf, GetBuffersWithFormatCookie, is_checked=is_checked
         )
 
+    def GetBuffersWithFormatChecked(
+        self, drawable, count, attachments_len, attachments
+    ):
+        return self.GetBuffersWithFormat(
+            drawable, count, attachments_len, attachments, is_checked=True
+        )
+
+    def GetBuffersWithFormatUnchecked(
+        self, drawable, count, attachments_len, attachments
+    ):
+        return self.GetBuffersWithFormat(
+            drawable, count, attachments_len, attachments, is_checked=False
+        )
+
     def SwapBuffers(
         self,
         drawable,
@@ -453,11 +513,59 @@ class dri2Extension(xcffib.Extension):
         )
         return self.send_request(8, buf, SwapBuffersCookie, is_checked=is_checked)
 
+    def SwapBuffersChecked(
+        self,
+        drawable,
+        target_msc_hi,
+        target_msc_lo,
+        divisor_hi,
+        divisor_lo,
+        remainder_hi,
+        remainder_lo,
+    ):
+        return self.SwapBuffers(
+            drawable,
+            target_msc_hi,
+            target_msc_lo,
+            divisor_hi,
+            divisor_lo,
+            remainder_hi,
+            remainder_lo,
+            is_checked=True,
+        )
+
+    def SwapBuffersUnchecked(
+        self,
+        drawable,
+        target_msc_hi,
+        target_msc_lo,
+        divisor_hi,
+        divisor_lo,
+        remainder_hi,
+        remainder_lo,
+    ):
+        return self.SwapBuffers(
+            drawable,
+            target_msc_hi,
+            target_msc_lo,
+            divisor_hi,
+            divisor_lo,
+            remainder_hi,
+            remainder_lo,
+            is_checked=False,
+        )
+
     def GetMSC(self, drawable, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", drawable))
         return self.send_request(9, buf, GetMSCCookie, is_checked=is_checked)
 
+    def GetMSCChecked(self, drawable):
+        return self.GetMSC(drawable, is_checked=True)
+
+    def GetMSCUnchecked(self, drawable):
+        return self.GetMSC(drawable, is_checked=False)
+
     def WaitMSC(
         self,
         drawable,
@@ -484,20 +592,80 @@ class dri2Extension(xcffib.Extension):
         )
         return self.send_request(10, buf, WaitMSCCookie, is_checked=is_checked)
 
+    def WaitMSCChecked(
+        self,
+        drawable,
+        target_msc_hi,
+        target_msc_lo,
+        divisor_hi,
+        divisor_lo,
+        remainder_hi,
+        remainder_lo,
+    ):
+        return self.WaitMSC(
+            drawable,
+            target_msc_hi,
+            target_msc_lo,
+            divisor_hi,
+            divisor_lo,
+            remainder_hi,
+            remainder_lo,
+            is_checked=True,
+        )
+
+    def WaitMSCUnchecked(
+        self,
+        drawable,
+        target_msc_hi,
+        target_msc_lo,
+        divisor_hi,
+        divisor_lo,
+        remainder_hi,
+        remainder_lo,
+    ):
+        return self.WaitMSC(
+            drawable,
+            target_msc_hi,
+            target_msc_lo,
+            divisor_hi,
+            divisor_lo,
+            remainder_hi,
+            remainder_lo,
+            is_checked=False,
+        )
+
     def WaitSBC(self, drawable, target_sbc_hi, target_sbc_lo, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIII", drawable, target_sbc_hi, target_sbc_lo))
         return self.send_request(11, buf, WaitSBCCookie, is_checked=is_checked)
 
+    def WaitSBCChecked(self, drawable, target_sbc_hi, target_sbc_lo):
+        return self.WaitSBC(drawable, target_sbc_hi, target_sbc_lo, is_checked=True)
+
+    def WaitSBCUnchecked(self, drawable, target_sbc_hi, target_sbc_lo):
+        return self.WaitSBC(drawable, target_sbc_hi, target_sbc_lo, is_checked=False)
+
     def SwapInterval(self, drawable, interval, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", drawable, interval))
         return self.send_request(12, buf, is_checked=is_checked)
 
+    def SwapIntervalChecked(self, drawable, interval):
+        return self.SwapInterval(drawable, interval, is_checked=True)
+
+    def SwapIntervalUnchecked(self, drawable, interval):
+        return self.SwapInterval(drawable, interval, is_checked=False)
+
     def GetParam(self, drawable, param, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", drawable, param))
         return self.send_request(13, buf, GetParamCookie, is_checked=is_checked)
 
+    def GetParamChecked(self, drawable, param):
+        return self.GetParam(drawable, param, is_checked=True)
+
+    def GetParamUnchecked(self, drawable, param):
+        return self.GetParam(drawable, param, is_checked=False)
+
 
 xcffib._add_ext(key, dri2Extension, _events, _errors)
