@@ -67,7 +67,7 @@ class Notify(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.window, self.serial = unpacker.unpack("II")
+        self.window, self.serial = unpacker.unpack("=II")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -93,7 +93,7 @@ class QueryVersionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.major_version, self.minor_version = unpacker.unpack("xx2x4xII")
+        self.major_version, self.minor_version = unpacker.unpack("=xx2x4xII")
         self.bufsize = unpacker.offset - base
 
 
@@ -109,7 +109,7 @@ class QueryCapabilitiesReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.capabilities,) = unpacker.unpack("xx2x4xI")
+        (self.capabilities,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -126,7 +126,7 @@ class GenericEvent(xcffib.Event):
         xcffib.Event.__init__(self, unpacker)
         base = unpacker.offset
         self.extension, self.length, self.evtype, self.event = unpacker.unpack(
-            "xB2xIH2xI"
+            "=xB2xIH2xI"
         )
         self.bufsize = unpacker.offset - base
 
@@ -176,7 +176,7 @@ class ConfigureNotifyEvent(xcffib.Event):
             self.pixmap_width,
             self.pixmap_height,
             self.pixmap_flags,
-        ) = unpacker.unpack("xx2x2xIIhhHHhhHHI")
+        ) = unpacker.unpack("=xx2x2xIIhhHHhhHHI")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -245,7 +245,7 @@ class IdleNotifyEvent(xcffib.Event):
         xcffib.Event.__init__(self, unpacker)
         base = unpacker.offset
         self.event, self.window, self.serial, self.pixmap, self.idle_fence = (
-            unpacker.unpack("xx2x2xIIIII")
+            unpacker.unpack("=xx2x2xIIIII")
         )
         self.bufsize = unpacker.offset - base
 
@@ -287,15 +287,33 @@ class presentExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2xII", major_version, minor_version))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 
+    def QueryVersionChecked(self, major_version, minor_version):
+        return self.QueryVersion(major_version, minor_version, is_checked=True)
+
+    def QueryVersionUnchecked(self, major_version, minor_version):
+        return self.QueryVersion(major_version, minor_version, is_checked=False)
+
     def SelectInput(self, eid, window, event_mask, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIII", eid, window, event_mask))
         return self.send_request(3, buf, is_checked=is_checked)
 
+    def SelectInputChecked(self, eid, window, event_mask):
+        return self.SelectInput(eid, window, event_mask, is_checked=True)
+
+    def SelectInputUnchecked(self, eid, window, event_mask):
+        return self.SelectInput(eid, window, event_mask, is_checked=False)
+
     def QueryCapabilities(self, target, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", target))
         return self.send_request(4, buf, QueryCapabilitiesCookie, is_checked=is_checked)
 
+    def QueryCapabilitiesChecked(self, target):
+        return self.QueryCapabilities(target, is_checked=True)
+
+    def QueryCapabilitiesUnchecked(self, target):
+        return self.QueryCapabilities(target, is_checked=False)
+
 
 xcffib._add_ext(key, presentExtension, _events, _errors)
