@@ -1394,6 +1394,12 @@ class randrExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2xII", major_version, minor_version))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 
+    def QueryVersionChecked(self, major_version, minor_version):
+        return self.QueryVersion(major_version, minor_version, is_checked=True)
+
+    def QueryVersionUnchecked(self, major_version, minor_version):
+        return self.QueryVersion(major_version, minor_version, is_checked=False)
+
     def SetScreenConfig(
         self,
         window,
@@ -1418,16 +1424,48 @@ class randrExtension(xcffib.Extension):
         )
         return self.send_request(2, buf, SetScreenConfigCookie, is_checked=is_checked)
 
+    def SetScreenConfigChecked(
+        self, window, timestamp, config_timestamp, sizeID, rotation, rate
+    ):
+        return self.SetScreenConfig(
+            window, timestamp, config_timestamp, sizeID, rotation, rate, is_checked=True
+        )
+
+    def SetScreenConfigUnchecked(
+        self, window, timestamp, config_timestamp, sizeID, rotation, rate
+    ):
+        return self.SetScreenConfig(
+            window,
+            timestamp,
+            config_timestamp,
+            sizeID,
+            rotation,
+            rate,
+            is_checked=False,
+        )
+
     def SelectInput(self, window, enable, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIH2x", window, enable))
         return self.send_request(4, buf, is_checked=is_checked)
 
+    def SelectInputChecked(self, window, enable):
+        return self.SelectInput(window, enable, is_checked=True)
+
+    def SelectInputUnchecked(self, window, enable):
+        return self.SelectInput(window, enable, is_checked=False)
+
     def GetScreenInfo(self, window, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
         return self.send_request(5, buf, GetScreenInfoCookie, is_checked=is_checked)
 
+    def GetScreenInfoChecked(self, window):
+        return self.GetScreenInfo(window, is_checked=True)
+
+    def GetScreenInfoUnchecked(self, window):
+        return self.GetScreenInfo(window, is_checked=False)
+
     def GetScreenSizeRange(self, window, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
@@ -1435,6 +1473,12 @@ class randrExtension(xcffib.Extension):
             6, buf, GetScreenSizeRangeCookie, is_checked=is_checked
         )
 
+    def GetScreenSizeRangeChecked(self, window):
+        return self.GetScreenSizeRange(window, is_checked=True)
+
+    def GetScreenSizeRangeUnchecked(self, window):
+        return self.GetScreenSizeRange(window, is_checked=False)
+
     def SetScreenSize(
         self, window, width, height, mm_width, mm_height, is_checked=False
     ):
@@ -1442,6 +1486,16 @@ class randrExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2xIHHII", window, width, height, mm_width, mm_height))
         return self.send_request(7, buf, is_checked=is_checked)
 
+    def SetScreenSizeChecked(self, window, width, height, mm_width, mm_height):
+        return self.SetScreenSize(
+            window, width, height, mm_width, mm_height, is_checked=True
+        )
+
+    def SetScreenSizeUnchecked(self, window, width, height, mm_width, mm_height):
+        return self.SetScreenSize(
+            window, width, height, mm_width, mm_height, is_checked=False
+        )
+
     def GetScreenResources(self, window, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
@@ -1449,11 +1503,23 @@ class randrExtension(xcffib.Extension):
             8, buf, GetScreenResourcesCookie, is_checked=is_checked
         )
 
+    def GetScreenResourcesChecked(self, window):
+        return self.GetScreenResources(window, is_checked=True)
+
+    def GetScreenResourcesUnchecked(self, window):
+        return self.GetScreenResources(window, is_checked=False)
+
     def GetOutputInfo(self, output, config_timestamp, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", output, config_timestamp))
         return self.send_request(9, buf, GetOutputInfoCookie, is_checked=is_checked)
 
+    def GetOutputInfoChecked(self, output, config_timestamp):
+        return self.GetOutputInfo(output, config_timestamp, is_checked=True)
+
+    def GetOutputInfoUnchecked(self, output, config_timestamp):
+        return self.GetOutputInfo(output, config_timestamp, is_checked=False)
+
     def ListOutputProperties(self, output, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", output))
@@ -1461,6 +1527,12 @@ class randrExtension(xcffib.Extension):
             10, buf, ListOutputPropertiesCookie, is_checked=is_checked
         )
 
+    def ListOutputPropertiesChecked(self, output):
+        return self.ListOutputProperties(output, is_checked=True)
+
+    def ListOutputPropertiesUnchecked(self, output):
+        return self.ListOutputProperties(output, is_checked=False)
+
     def QueryOutputProperty(self, output, property, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", output, property))
@@ -1468,6 +1540,12 @@ class randrExtension(xcffib.Extension):
             11, buf, QueryOutputPropertyCookie, is_checked=is_checked
         )
 
+    def QueryOutputPropertyChecked(self, output, property):
+        return self.QueryOutputProperty(output, property, is_checked=True)
+
+    def QueryOutputPropertyUnchecked(self, output, property):
+        return self.QueryOutputProperty(output, property, is_checked=False)
+
     def ConfigureOutputProperty(
         self, output, property, pending, range, values_len, values, is_checked=False
     ):
@@ -1476,6 +1554,20 @@ class randrExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(values, "i"))
         return self.send_request(12, buf, is_checked=is_checked)
 
+    def ConfigureOutputPropertyChecked(
+        self, output, property, pending, range, values_len, values
+    ):
+        return self.ConfigureOutputProperty(
+            output, property, pending, range, values_len, values, is_checked=True
+        )
+
+    def ConfigureOutputPropertyUnchecked(
+        self, output, property, pending, range, values_len, values
+    ):
+        return self.ConfigureOutputProperty(
+            output, property, pending, range, values_len, values, is_checked=False
+        )
+
     def ChangeOutputProperty(
         self, output, property, type, format, mode, num_units, data, is_checked=False
     ):
@@ -1488,11 +1580,31 @@ class randrExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(data, "c"))
         return self.send_request(13, buf, is_checked=is_checked)
 
+    def ChangeOutputPropertyChecked(
+        self, output, property, type, format, mode, num_units, data
+    ):
+        return self.ChangeOutputProperty(
+            output, property, type, format, mode, num_units, data, is_checked=True
+        )
+
+    def ChangeOutputPropertyUnchecked(
+        self, output, property, type, format, mode, num_units, data
+    ):
+        return self.ChangeOutputProperty(
+            output, property, type, format, mode, num_units, data, is_checked=False
+        )
+
     def DeleteOutputProperty(self, output, property, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", output, property))
         return self.send_request(14, buf, is_checked=is_checked)
 
+    def DeleteOutputPropertyChecked(self, output, property):
+        return self.DeleteOutputProperty(output, property, is_checked=True)
+
+    def DeleteOutputPropertyUnchecked(self, output, property):
+        return self.DeleteOutputProperty(output, property, is_checked=False)
+
     def GetOutputProperty(
         self,
         output,
@@ -1521,6 +1633,34 @@ class randrExtension(xcffib.Extension):
             15, buf, GetOutputPropertyCookie, is_checked=is_checked
         )
 
+    def GetOutputPropertyChecked(
+        self, output, property, type, long_offset, long_length, delete, pending
+    ):
+        return self.GetOutputProperty(
+            output,
+            property,
+            type,
+            long_offset,
+            long_length,
+            delete,
+            pending,
+            is_checked=True,
+        )
+
+    def GetOutputPropertyUnchecked(
+        self, output, property, type, long_offset, long_length, delete, pending
+    ):
+        return self.GetOutputProperty(
+            output,
+            property,
+            type,
+            long_offset,
+            long_length,
+            delete,
+            pending,
+            is_checked=False,
+        )
+
     def CreateMode(self, window, mode_info, name_len, name, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
@@ -1532,26 +1672,56 @@ class randrExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(name, "c"))
         return self.send_request(16, buf, CreateModeCookie, is_checked=is_checked)
 
+    def CreateModeChecked(self, window, mode_info, name_len, name):
+        return self.CreateMode(window, mode_info, name_len, name, is_checked=True)
+
+    def CreateModeUnchecked(self, window, mode_info, name_len, name):
+        return self.CreateMode(window, mode_info, name_len, name, is_checked=False)
+
     def DestroyMode(self, mode, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", mode))
         return self.send_request(17, buf, is_checked=is_checked)
 
+    def DestroyModeChecked(self, mode):
+        return self.DestroyMode(mode, is_checked=True)
+
+    def DestroyModeUnchecked(self, mode):
+        return self.DestroyMode(mode, is_checked=False)
+
     def AddOutputMode(self, output, mode, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", output, mode))
         return self.send_request(18, buf, is_checked=is_checked)
 
+    def AddOutputModeChecked(self, output, mode):
+        return self.AddOutputMode(output, mode, is_checked=True)
+
+    def AddOutputModeUnchecked(self, output, mode):
+        return self.AddOutputMode(output, mode, is_checked=False)
+
     def DeleteOutputMode(self, output, mode, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", output, mode))
         return self.send_request(19, buf, is_checked=is_checked)
 
+    def DeleteOutputModeChecked(self, output, mode):
+        return self.DeleteOutputMode(output, mode, is_checked=True)
+
+    def DeleteOutputModeUnchecked(self, output, mode):
+        return self.DeleteOutputMode(output, mode, is_checked=False)
+
     def GetCrtcInfo(self, crtc, config_timestamp, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", crtc, config_timestamp))
         return self.send_request(20, buf, GetCrtcInfoCookie, is_checked=is_checked)
 
+    def GetCrtcInfoChecked(self, crtc, config_timestamp):
+        return self.GetCrtcInfo(crtc, config_timestamp, is_checked=True)
+
+    def GetCrtcInfoUnchecked(self, crtc, config_timestamp):
+        return self.GetCrtcInfo(crtc, config_timestamp, is_checked=False)
+
     def SetCrtcConfig(
         self,
         crtc,
@@ -1581,16 +1751,78 @@ class randrExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(outputs, "I"))
         return self.send_request(21, buf, SetCrtcConfigCookie, is_checked=is_checked)
 
+    def SetCrtcConfigChecked(
+        self,
+        crtc,
+        timestamp,
+        config_timestamp,
+        x,
+        y,
+        mode,
+        rotation,
+        outputs_len,
+        outputs,
+    ):
+        return self.SetCrtcConfig(
+            crtc,
+            timestamp,
+            config_timestamp,
+            x,
+            y,
+            mode,
+            rotation,
+            outputs_len,
+            outputs,
+            is_checked=True,
+        )
+
+    def SetCrtcConfigUnchecked(
+        self,
+        crtc,
+        timestamp,
+        config_timestamp,
+        x,
+        y,
+        mode,
+        rotation,
+        outputs_len,
+        outputs,
+    ):
+        return self.SetCrtcConfig(
+            crtc,
+            timestamp,
+            config_timestamp,
+            x,
+            y,
+            mode,
+            rotation,
+            outputs_len,
+            outputs,
+            is_checked=False,
+        )
+
     def GetCrtcGammaSize(self, crtc, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", crtc))
         return self.send_request(22, buf, GetCrtcGammaSizeCookie, is_checked=is_checked)
 
+    def GetCrtcGammaSizeChecked(self, crtc):
+        return self.GetCrtcGammaSize(crtc, is_checked=True)
+
+    def GetCrtcGammaSizeUnchecked(self, crtc):
+        return self.GetCrtcGammaSize(crtc, is_checked=False)
+
     def GetCrtcGamma(self, crtc, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", crtc))
         return self.send_request(23, buf, GetCrtcGammaCookie, is_checked=is_checked)
 
+    def GetCrtcGammaChecked(self, crtc):
+        return self.GetCrtcGamma(crtc, is_checked=True)
+
+    def GetCrtcGammaUnchecked(self, crtc):
+        return self.GetCrtcGamma(crtc, is_checked=False)
+
     def SetCrtcGamma(self, crtc, size, red, green, blue, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIH2x", crtc, size))
@@ -1599,6 +1831,12 @@ class randrExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(blue, "H"))
         return self.send_request(24, buf, is_checked=is_checked)
 
+    def SetCrtcGammaChecked(self, crtc, size, red, green, blue):
+        return self.SetCrtcGamma(crtc, size, red, green, blue, is_checked=True)
+
+    def SetCrtcGammaUnchecked(self, crtc, size, red, green, blue):
+        return self.SetCrtcGamma(crtc, size, red, green, blue, is_checked=False)
+
     def GetScreenResourcesCurrent(self, window, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
@@ -1606,6 +1844,12 @@ class randrExtension(xcffib.Extension):
             25, buf, GetScreenResourcesCurrentCookie, is_checked=is_checked
         )
 
+    def GetScreenResourcesCurrentChecked(self, window):
+        return self.GetScreenResourcesCurrent(window, is_checked=True)
+
+    def GetScreenResourcesCurrentUnchecked(self, window):
+        return self.GetScreenResourcesCurrent(window, is_checked=False)
+
     def SetCrtcTransform(
         self,
         crtc,
@@ -1638,16 +1882,54 @@ class randrExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(filter_params, "i"))
         return self.send_request(26, buf, is_checked=is_checked)
 
+    def SetCrtcTransformChecked(
+        self, crtc, transform, filter_len, filter_name, filter_params_len, filter_params
+    ):
+        return self.SetCrtcTransform(
+            crtc,
+            transform,
+            filter_len,
+            filter_name,
+            filter_params_len,
+            filter_params,
+            is_checked=True,
+        )
+
+    def SetCrtcTransformUnchecked(
+        self, crtc, transform, filter_len, filter_name, filter_params_len, filter_params
+    ):
+        return self.SetCrtcTransform(
+            crtc,
+            transform,
+            filter_len,
+            filter_name,
+            filter_params_len,
+            filter_params,
+            is_checked=False,
+        )
+
     def GetCrtcTransform(self, crtc, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", crtc))
         return self.send_request(27, buf, GetCrtcTransformCookie, is_checked=is_checked)
 
+    def GetCrtcTransformChecked(self, crtc):
+        return self.GetCrtcTransform(crtc, is_checked=True)
+
+    def GetCrtcTransformUnchecked(self, crtc):
+        return self.GetCrtcTransform(crtc, is_checked=False)
+
     def GetPanning(self, crtc, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", crtc))
         return self.send_request(28, buf, GetPanningCookie, is_checked=is_checked)
 
+    def GetPanningChecked(self, crtc):
+        return self.GetPanning(crtc, is_checked=True)
+
+    def GetPanningUnchecked(self, crtc):
+        return self.GetPanning(crtc, is_checked=False)
+
     def SetPanning(
         self,
         crtc,
@@ -1688,26 +1970,120 @@ class randrExtension(xcffib.Extension):
         )
         return self.send_request(29, buf, SetPanningCookie, is_checked=is_checked)
 
+    def SetPanningChecked(
+        self,
+        crtc,
+        timestamp,
+        left,
+        top,
+        width,
+        height,
+        track_left,
+        track_top,
+        track_width,
+        track_height,
+        border_left,
+        border_top,
+        border_right,
+        border_bottom,
+    ):
+        return self.SetPanning(
+            crtc,
+            timestamp,
+            left,
+            top,
+            width,
+            height,
+            track_left,
+            track_top,
+            track_width,
+            track_height,
+            border_left,
+            border_top,
+            border_right,
+            border_bottom,
+            is_checked=True,
+        )
+
+    def SetPanningUnchecked(
+        self,
+        crtc,
+        timestamp,
+        left,
+        top,
+        width,
+        height,
+        track_left,
+        track_top,
+        track_width,
+        track_height,
+        border_left,
+        border_top,
+        border_right,
+        border_bottom,
+    ):
+        return self.SetPanning(
+            crtc,
+            timestamp,
+            left,
+            top,
+            width,
+            height,
+            track_left,
+            track_top,
+            track_width,
+            track_height,
+            border_left,
+            border_top,
+            border_right,
+            border_bottom,
+            is_checked=False,
+        )
+
     def SetOutputPrimary(self, window, output, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", window, output))
         return self.send_request(30, buf, is_checked=is_checked)
 
+    def SetOutputPrimaryChecked(self, window, output):
+        return self.SetOutputPrimary(window, output, is_checked=True)
+
+    def SetOutputPrimaryUnchecked(self, window, output):
+        return self.SetOutputPrimary(window, output, is_checked=False)
+
     def GetOutputPrimary(self, window, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
         return self.send_request(31, buf, GetOutputPrimaryCookie, is_checked=is_checked)
 
+    def GetOutputPrimaryChecked(self, window):
+        return self.GetOutputPrimary(window, is_checked=True)
+
+    def GetOutputPrimaryUnchecked(self, window):
+        return self.GetOutputPrimary(window, is_checked=False)
+
     def GetProviders(self, window, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
         return self.send_request(32, buf, GetProvidersCookie, is_checked=is_checked)
 
+    def GetProvidersChecked(self, window):
+        return self.GetProviders(window, is_checked=True)
+
+    def GetProvidersUnchecked(self, window):
+        return self.GetProviders(window, is_checked=False)
+
     def GetProviderInfo(self, provider, config_timestamp, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", provider, config_timestamp))
         return self.send_request(33, buf, GetProviderInfoCookie, is_checked=is_checked)
 
+    def GetProviderInfoChecked(self, provider, config_timestamp):
+        return self.GetProviderInfo(provider, config_timestamp, is_checked=True)
+
+    def GetProviderInfoUnchecked(self, provider, config_timestamp):
+        return self.GetProviderInfo(provider, config_timestamp, is_checked=False)
+
     def SetProviderOffloadSink(
         self, provider, sink_provider, config_timestamp, is_checked=False
     ):
@@ -1715,6 +2091,18 @@ class randrExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2xIII", provider, sink_provider, config_timestamp))
         return self.send_request(34, buf, is_checked=is_checked)
 
+    def SetProviderOffloadSinkChecked(self, provider, sink_provider, config_timestamp):
+        return self.SetProviderOffloadSink(
+            provider, sink_provider, config_timestamp, is_checked=True
+        )
+
+    def SetProviderOffloadSinkUnchecked(
+        self, provider, sink_provider, config_timestamp
+    ):
+        return self.SetProviderOffloadSink(
+            provider, sink_provider, config_timestamp, is_checked=False
+        )
+
     def SetProviderOutputSource(
         self, provider, source_provider, config_timestamp, is_checked=False
     ):
@@ -1722,6 +2110,20 @@ class randrExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2xIII", provider, source_provider, config_timestamp))
         return self.send_request(35, buf, is_checked=is_checked)
 
+    def SetProviderOutputSourceChecked(
+        self, provider, source_provider, config_timestamp
+    ):
+        return self.SetProviderOutputSource(
+            provider, source_provider, config_timestamp, is_checked=True
+        )
+
+    def SetProviderOutputSourceUnchecked(
+        self, provider, source_provider, config_timestamp
+    ):
+        return self.SetProviderOutputSource(
+            provider, source_provider, config_timestamp, is_checked=False
+        )
+
     def ListProviderProperties(self, provider, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", provider))
@@ -1729,6 +2131,12 @@ class randrExtension(xcffib.Extension):
             36, buf, ListProviderPropertiesCookie, is_checked=is_checked
         )
 
+    def ListProviderPropertiesChecked(self, provider):
+        return self.ListProviderProperties(provider, is_checked=True)
+
+    def ListProviderPropertiesUnchecked(self, provider):
+        return self.ListProviderProperties(provider, is_checked=False)
+
     def QueryProviderProperty(self, provider, property, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", provider, property))
@@ -1736,6 +2144,12 @@ class randrExtension(xcffib.Extension):
             37, buf, QueryProviderPropertyCookie, is_checked=is_checked
         )
 
+    def QueryProviderPropertyChecked(self, provider, property):
+        return self.QueryProviderProperty(provider, property, is_checked=True)
+
+    def QueryProviderPropertyUnchecked(self, provider, property):
+        return self.QueryProviderProperty(provider, property, is_checked=False)
+
     def ConfigureProviderProperty(
         self, provider, property, pending, range, values_len, values, is_checked=False
     ):
@@ -1744,6 +2158,20 @@ class randrExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(values, "i"))
         return self.send_request(38, buf, is_checked=is_checked)
 
+    def ConfigureProviderPropertyChecked(
+        self, provider, property, pending, range, values_len, values
+    ):
+        return self.ConfigureProviderProperty(
+            provider, property, pending, range, values_len, values, is_checked=True
+        )
+
+    def ConfigureProviderPropertyUnchecked(
+        self, provider, property, pending, range, values_len, values
+    ):
+        return self.ConfigureProviderProperty(
+            provider, property, pending, range, values_len, values, is_checked=False
+        )
+
     def ChangeProviderProperty(
         self, provider, property, type, format, mode, num_items, data, is_checked=False
     ):
@@ -1756,11 +2184,31 @@ class randrExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(data, "c"))
         return self.send_request(39, buf, is_checked=is_checked)
 
+    def ChangeProviderPropertyChecked(
+        self, provider, property, type, format, mode, num_items, data
+    ):
+        return self.ChangeProviderProperty(
+            provider, property, type, format, mode, num_items, data, is_checked=True
+        )
+
+    def ChangeProviderPropertyUnchecked(
+        self, provider, property, type, format, mode, num_items, data
+    ):
+        return self.ChangeProviderProperty(
+            provider, property, type, format, mode, num_items, data, is_checked=False
+        )
+
     def DeleteProviderProperty(self, provider, property, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", provider, property))
         return self.send_request(40, buf, is_checked=is_checked)
 
+    def DeleteProviderPropertyChecked(self, provider, property):
+        return self.DeleteProviderProperty(provider, property, is_checked=True)
+
+    def DeleteProviderPropertyUnchecked(self, provider, property):
+        return self.DeleteProviderProperty(provider, property, is_checked=False)
+
     def GetProviderProperty(
         self,
         provider,
@@ -1789,11 +2237,45 @@ class randrExtension(xcffib.Extension):
             41, buf, GetProviderPropertyCookie, is_checked=is_checked
         )
 
+    def GetProviderPropertyChecked(
+        self, provider, property, type, long_offset, long_length, delete, pending
+    ):
+        return self.GetProviderProperty(
+            provider,
+            property,
+            type,
+            long_offset,
+            long_length,
+            delete,
+            pending,
+            is_checked=True,
+        )
+
+    def GetProviderPropertyUnchecked(
+        self, provider, property, type, long_offset, long_length, delete, pending
+    ):
+        return self.GetProviderProperty(
+            provider,
+            property,
+            type,
+            long_offset,
+            long_length,
+            delete,
+            pending,
+            is_checked=False,
+        )
+
     def GetMonitors(self, window, get_active, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIB", window, get_active))
         return self.send_request(42, buf, GetMonitorsCookie, is_checked=is_checked)
 
+    def GetMonitorsChecked(self, window, get_active):
+        return self.GetMonitors(window, get_active, is_checked=True)
+
+    def GetMonitorsUnchecked(self, window, get_active):
+        return self.GetMonitors(window, get_active, is_checked=False)
+
     def SetMonitor(self, window, monitorinfo, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
@@ -1804,11 +2286,23 @@ class randrExtension(xcffib.Extension):
         )
         return self.send_request(43, buf, is_checked=is_checked)
 
+    def SetMonitorChecked(self, window, monitorinfo):
+        return self.SetMonitor(window, monitorinfo, is_checked=True)
+
+    def SetMonitorUnchecked(self, window, monitorinfo):
+        return self.SetMonitor(window, monitorinfo, is_checked=False)
+
     def DeleteMonitor(self, window, name, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", window, name))
         return self.send_request(44, buf, is_checked=is_checked)
 
+    def DeleteMonitorChecked(self, window, name):
+        return self.DeleteMonitor(window, name, is_checked=True)
+
+    def DeleteMonitorUnchecked(self, window, name):
+        return self.DeleteMonitor(window, name, is_checked=False)
+
     def CreateLease(
         self, window, lid, num_crtcs, num_outputs, crtcs, outputs, is_checked=True
     ):
@@ -1818,10 +2312,26 @@ class randrExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(outputs, "I"))
         return self.send_request(45, buf, CreateLeaseCookie, is_checked=is_checked)
 
+    def CreateLeaseChecked(self, window, lid, num_crtcs, num_outputs, crtcs, outputs):
+        return self.CreateLease(
+            window, lid, num_crtcs, num_outputs, crtcs, outputs, is_checked=True
+        )
+
+    def CreateLeaseUnchecked(self, window, lid, num_crtcs, num_outputs, crtcs, outputs):
+        return self.CreateLease(
+            window, lid, num_crtcs, num_outputs, crtcs, outputs, is_checked=False
+        )
+
     def FreeLease(self, lid, terminate, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIB", lid, terminate))
         return self.send_request(46, buf, is_checked=is_checked)
 
+    def FreeLeaseChecked(self, lid, terminate):
+        return self.FreeLease(lid, terminate, is_checked=True)
+
+    def FreeLeaseUnchecked(self, lid, terminate):
+        return self.FreeLease(lid, terminate, is_checked=False)
+
 
 xcffib._add_ext(key, randrExtension, _events, _errors)
