@@ -893,11 +893,27 @@ class renderExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2xII", client_major_version, client_minor_version))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 
+    def QueryVersionChecked(self, client_major_version, client_minor_version):
+        return self.QueryVersion(
+            client_major_version, client_minor_version, is_checked=True
+        )
+
+    def QueryVersionUnchecked(self, client_major_version, client_minor_version):
+        return self.QueryVersion(
+            client_major_version, client_minor_version, is_checked=False
+        )
+
     def QueryPictFormats(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(1, buf, QueryPictFormatsCookie, is_checked=is_checked)
 
+    def QueryPictFormatsChecked(self):
+        return self.QueryPictFormats(is_checked=True)
+
+    def QueryPictFormatsUnchecked(self):
+        return self.QueryPictFormats(is_checked=False)
+
     def QueryPictIndexValues(self, format, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", format))
@@ -905,6 +921,12 @@ class renderExtension(xcffib.Extension):
             2, buf, QueryPictIndexValuesCookie, is_checked=is_checked
         )
 
+    def QueryPictIndexValuesChecked(self, format):
+        return self.QueryPictIndexValues(format, is_checked=True)
+
+    def QueryPictIndexValuesUnchecked(self, format):
+        return self.QueryPictIndexValues(format, is_checked=False)
+
     def CreatePicture(
         self, pid, drawable, format, value_mask, value_list, is_checked=False
     ):
@@ -951,6 +973,16 @@ class renderExtension(xcffib.Extension):
             buf.write(struct.pack("=I", componentalpha))
         return self.send_request(4, buf, is_checked=is_checked)
 
+    def CreatePictureChecked(self, pid, drawable, format, value_mask, value_list):
+        return self.CreatePicture(
+            pid, drawable, format, value_mask, value_list, is_checked=True
+        )
+
+    def CreatePictureUnchecked(self, pid, drawable, format, value_mask, value_list):
+        return self.CreatePicture(
+            pid, drawable, format, value_mask, value_list, is_checked=False
+        )
+
     def ChangePicture(self, picture, value_mask, value_list, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", picture, value_mask))
@@ -995,6 +1027,12 @@ class renderExtension(xcffib.Extension):
             buf.write(struct.pack("=I", componentalpha))
         return self.send_request(5, buf, is_checked=is_checked)
 
+    def ChangePictureChecked(self, picture, value_mask, value_list):
+        return self.ChangePicture(picture, value_mask, value_list, is_checked=True)
+
+    def ChangePictureUnchecked(self, picture, value_mask, value_list):
+        return self.ChangePicture(picture, value_mask, value_list, is_checked=False)
+
     def SetPictureClipRectangles(
         self,
         picture,
@@ -1009,11 +1047,41 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(rectangles, xproto.RECTANGLE))
         return self.send_request(6, buf, is_checked=is_checked)
 
+    def SetPictureClipRectanglesChecked(
+        self, picture, clip_x_origin, clip_y_origin, rectangles_len, rectangles
+    ):
+        return self.SetPictureClipRectangles(
+            picture,
+            clip_x_origin,
+            clip_y_origin,
+            rectangles_len,
+            rectangles,
+            is_checked=True,
+        )
+
+    def SetPictureClipRectanglesUnchecked(
+        self, picture, clip_x_origin, clip_y_origin, rectangles_len, rectangles
+    ):
+        return self.SetPictureClipRectangles(
+            picture,
+            clip_x_origin,
+            clip_y_origin,
+            rectangles_len,
+            rectangles,
+            is_checked=False,
+        )
+
     def FreePicture(self, picture, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", picture))
         return self.send_request(7, buf, is_checked=is_checked)
 
+    def FreePictureChecked(self, picture):
+        return self.FreePicture(picture, is_checked=True)
+
+    def FreePictureUnchecked(self, picture):
+        return self.FreePicture(picture, is_checked=False)
+
     def Composite(
         self,
         op,
@@ -1050,6 +1118,68 @@ class renderExtension(xcffib.Extension):
         )
         return self.send_request(8, buf, is_checked=is_checked)
 
+    def CompositeChecked(
+        self,
+        op,
+        src,
+        mask,
+        dst,
+        src_x,
+        src_y,
+        mask_x,
+        mask_y,
+        dst_x,
+        dst_y,
+        width,
+        height,
+    ):
+        return self.Composite(
+            op,
+            src,
+            mask,
+            dst,
+            src_x,
+            src_y,
+            mask_x,
+            mask_y,
+            dst_x,
+            dst_y,
+            width,
+            height,
+            is_checked=True,
+        )
+
+    def CompositeUnchecked(
+        self,
+        op,
+        src,
+        mask,
+        dst,
+        src_x,
+        src_y,
+        mask_x,
+        mask_y,
+        dst_x,
+        dst_y,
+        width,
+        height,
+    ):
+        return self.Composite(
+            op,
+            src,
+            mask,
+            dst,
+            src_x,
+            src_y,
+            mask_x,
+            mask_y,
+            dst_x,
+            dst_y,
+            width,
+            height,
+            is_checked=False,
+        )
+
     def Trapezoids(
         self,
         op,
@@ -1067,6 +1197,20 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(traps, TRAPEZOID))
         return self.send_request(10, buf, is_checked=is_checked)
 
+    def TrapezoidsChecked(
+        self, op, src, dst, mask_format, src_x, src_y, traps_len, traps
+    ):
+        return self.Trapezoids(
+            op, src, dst, mask_format, src_x, src_y, traps_len, traps, is_checked=True
+        )
+
+    def TrapezoidsUnchecked(
+        self, op, src, dst, mask_format, src_x, src_y, traps_len, traps
+    ):
+        return self.Trapezoids(
+            op, src, dst, mask_format, src_x, src_y, traps_len, traps, is_checked=False
+        )
+
     def Triangles(
         self,
         op,
@@ -1084,6 +1228,36 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(triangles, TRIANGLE))
         return self.send_request(11, buf, is_checked=is_checked)
 
+    def TrianglesChecked(
+        self, op, src, dst, mask_format, src_x, src_y, triangles_len, triangles
+    ):
+        return self.Triangles(
+            op,
+            src,
+            dst,
+            mask_format,
+            src_x,
+            src_y,
+            triangles_len,
+            triangles,
+            is_checked=True,
+        )
+
+    def TrianglesUnchecked(
+        self, op, src, dst, mask_format, src_x, src_y, triangles_len, triangles
+    ):
+        return self.Triangles(
+            op,
+            src,
+            dst,
+            mask_format,
+            src_x,
+            src_y,
+            triangles_len,
+            triangles,
+            is_checked=False,
+        )
+
     def TriStrip(
         self,
         op,
@@ -1101,6 +1275,28 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(points, POINTFIX))
         return self.send_request(12, buf, is_checked=is_checked)
 
+    def TriStripChecked(
+        self, op, src, dst, mask_format, src_x, src_y, points_len, points
+    ):
+        return self.TriStrip(
+            op, src, dst, mask_format, src_x, src_y, points_len, points, is_checked=True
+        )
+
+    def TriStripUnchecked(
+        self, op, src, dst, mask_format, src_x, src_y, points_len, points
+    ):
+        return self.TriStrip(
+            op,
+            src,
+            dst,
+            mask_format,
+            src_x,
+            src_y,
+            points_len,
+            points,
+            is_checked=False,
+        )
+
     def TriFan(
         self,
         op,
@@ -1118,21 +1314,61 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(points, POINTFIX))
         return self.send_request(13, buf, is_checked=is_checked)
 
+    def TriFanChecked(
+        self, op, src, dst, mask_format, src_x, src_y, points_len, points
+    ):
+        return self.TriFan(
+            op, src, dst, mask_format, src_x, src_y, points_len, points, is_checked=True
+        )
+
+    def TriFanUnchecked(
+        self, op, src, dst, mask_format, src_x, src_y, points_len, points
+    ):
+        return self.TriFan(
+            op,
+            src,
+            dst,
+            mask_format,
+            src_x,
+            src_y,
+            points_len,
+            points,
+            is_checked=False,
+        )
+
     def CreateGlyphSet(self, gsid, format, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", gsid, format))
         return self.send_request(17, buf, is_checked=is_checked)
 
+    def CreateGlyphSetChecked(self, gsid, format):
+        return self.CreateGlyphSet(gsid, format, is_checked=True)
+
+    def CreateGlyphSetUnchecked(self, gsid, format):
+        return self.CreateGlyphSet(gsid, format, is_checked=False)
+
     def ReferenceGlyphSet(self, gsid, existing, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", gsid, existing))
         return self.send_request(18, buf, is_checked=is_checked)
 
+    def ReferenceGlyphSetChecked(self, gsid, existing):
+        return self.ReferenceGlyphSet(gsid, existing, is_checked=True)
+
+    def ReferenceGlyphSetUnchecked(self, gsid, existing):
+        return self.ReferenceGlyphSet(gsid, existing, is_checked=False)
+
     def FreeGlyphSet(self, glyphset, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", glyphset))
         return self.send_request(19, buf, is_checked=is_checked)
 
+    def FreeGlyphSetChecked(self, glyphset):
+        return self.FreeGlyphSet(glyphset, is_checked=True)
+
+    def FreeGlyphSetUnchecked(self, glyphset):
+        return self.FreeGlyphSet(glyphset, is_checked=False)
+
     def AddGlyphs(
         self, glyphset, glyphs_len, glyphids, glyphs, data_len, data, is_checked=False
     ):
@@ -1143,12 +1379,30 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(data, "B"))
         return self.send_request(20, buf, is_checked=is_checked)
 
+    def AddGlyphsChecked(self, glyphset, glyphs_len, glyphids, glyphs, data_len, data):
+        return self.AddGlyphs(
+            glyphset, glyphs_len, glyphids, glyphs, data_len, data, is_checked=True
+        )
+
+    def AddGlyphsUnchecked(
+        self, glyphset, glyphs_len, glyphids, glyphs, data_len, data
+    ):
+        return self.AddGlyphs(
+            glyphset, glyphs_len, glyphids, glyphs, data_len, data, is_checked=False
+        )
+
     def FreeGlyphs(self, glyphset, glyphs_len, glyphs, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", glyphset))
         buf.write(xcffib.pack_list(glyphs, "I"))
         return self.send_request(22, buf, is_checked=is_checked)
 
+    def FreeGlyphsChecked(self, glyphset, glyphs_len, glyphs):
+        return self.FreeGlyphs(glyphset, glyphs_len, glyphs, is_checked=True)
+
+    def FreeGlyphsUnchecked(self, glyphset, glyphs_len, glyphs):
+        return self.FreeGlyphs(glyphset, glyphs_len, glyphs, is_checked=False)
+
     def CompositeGlyphs8(
         self,
         op,
@@ -1171,6 +1425,56 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(glyphcmds, "B"))
         return self.send_request(23, buf, is_checked=is_checked)
 
+    def CompositeGlyphs8Checked(
+        self,
+        op,
+        src,
+        dst,
+        mask_format,
+        glyphset,
+        src_x,
+        src_y,
+        glyphcmds_len,
+        glyphcmds,
+    ):
+        return self.CompositeGlyphs8(
+            op,
+            src,
+            dst,
+            mask_format,
+            glyphset,
+            src_x,
+            src_y,
+            glyphcmds_len,
+            glyphcmds,
+            is_checked=True,
+        )
+
+    def CompositeGlyphs8Unchecked(
+        self,
+        op,
+        src,
+        dst,
+        mask_format,
+        glyphset,
+        src_x,
+        src_y,
+        glyphcmds_len,
+        glyphcmds,
+    ):
+        return self.CompositeGlyphs8(
+            op,
+            src,
+            dst,
+            mask_format,
+            glyphset,
+            src_x,
+            src_y,
+            glyphcmds_len,
+            glyphcmds,
+            is_checked=False,
+        )
+
     def CompositeGlyphs16(
         self,
         op,
@@ -1193,6 +1497,56 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(glyphcmds, "B"))
         return self.send_request(24, buf, is_checked=is_checked)
 
+    def CompositeGlyphs16Checked(
+        self,
+        op,
+        src,
+        dst,
+        mask_format,
+        glyphset,
+        src_x,
+        src_y,
+        glyphcmds_len,
+        glyphcmds,
+    ):
+        return self.CompositeGlyphs16(
+            op,
+            src,
+            dst,
+            mask_format,
+            glyphset,
+            src_x,
+            src_y,
+            glyphcmds_len,
+            glyphcmds,
+            is_checked=True,
+        )
+
+    def CompositeGlyphs16Unchecked(
+        self,
+        op,
+        src,
+        dst,
+        mask_format,
+        glyphset,
+        src_x,
+        src_y,
+        glyphcmds_len,
+        glyphcmds,
+    ):
+        return self.CompositeGlyphs16(
+            op,
+            src,
+            dst,
+            mask_format,
+            glyphset,
+            src_x,
+            src_y,
+            glyphcmds_len,
+            glyphcmds,
+            is_checked=False,
+        )
+
     def CompositeGlyphs32(
         self,
         op,
@@ -1215,6 +1569,56 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(glyphcmds, "B"))
         return self.send_request(25, buf, is_checked=is_checked)
 
+    def CompositeGlyphs32Checked(
+        self,
+        op,
+        src,
+        dst,
+        mask_format,
+        glyphset,
+        src_x,
+        src_y,
+        glyphcmds_len,
+        glyphcmds,
+    ):
+        return self.CompositeGlyphs32(
+            op,
+            src,
+            dst,
+            mask_format,
+            glyphset,
+            src_x,
+            src_y,
+            glyphcmds_len,
+            glyphcmds,
+            is_checked=True,
+        )
+
+    def CompositeGlyphs32Unchecked(
+        self,
+        op,
+        src,
+        dst,
+        mask_format,
+        glyphset,
+        src_x,
+        src_y,
+        glyphcmds_len,
+        glyphcmds,
+    ):
+        return self.CompositeGlyphs32(
+            op,
+            src,
+            dst,
+            mask_format,
+            glyphset,
+            src_x,
+            src_y,
+            glyphcmds_len,
+            glyphcmds,
+            is_checked=False,
+        )
+
     def FillRectangles(self, op, dst, color, rects_len, rects, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB3xI", op, dst))
@@ -1224,11 +1628,23 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(rects, xproto.RECTANGLE))
         return self.send_request(26, buf, is_checked=is_checked)
 
+    def FillRectanglesChecked(self, op, dst, color, rects_len, rects):
+        return self.FillRectangles(op, dst, color, rects_len, rects, is_checked=True)
+
+    def FillRectanglesUnchecked(self, op, dst, color, rects_len, rects):
+        return self.FillRectangles(op, dst, color, rects_len, rects, is_checked=False)
+
     def CreateCursor(self, cid, source, x, y, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIHH", cid, source, x, y))
         return self.send_request(27, buf, is_checked=is_checked)
 
+    def CreateCursorChecked(self, cid, source, x, y):
+        return self.CreateCursor(cid, source, x, y, is_checked=True)
+
+    def CreateCursorUnchecked(self, cid, source, x, y):
+        return self.CreateCursor(cid, source, x, y, is_checked=False)
+
     def SetPictureTransform(self, picture, transform, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", picture))
@@ -1239,11 +1655,23 @@ class renderExtension(xcffib.Extension):
         )
         return self.send_request(28, buf, is_checked=is_checked)
 
+    def SetPictureTransformChecked(self, picture, transform):
+        return self.SetPictureTransform(picture, transform, is_checked=True)
+
+    def SetPictureTransformUnchecked(self, picture, transform):
+        return self.SetPictureTransform(picture, transform, is_checked=False)
+
     def QueryFilters(self, drawable, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", drawable))
         return self.send_request(29, buf, QueryFiltersCookie, is_checked=is_checked)
 
+    def QueryFiltersChecked(self, drawable):
+        return self.QueryFilters(drawable, is_checked=True)
+
+    def QueryFiltersUnchecked(self, drawable):
+        return self.QueryFilters(drawable, is_checked=False)
+
     def SetPictureFilter(
         self, picture, filter_len, filter, values_len, values, is_checked=False
     ):
@@ -1258,18 +1686,42 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(values, "i"))
         return self.send_request(30, buf, is_checked=is_checked)
 
+    def SetPictureFilterChecked(self, picture, filter_len, filter, values_len, values):
+        return self.SetPictureFilter(
+            picture, filter_len, filter, values_len, values, is_checked=True
+        )
+
+    def SetPictureFilterUnchecked(
+        self, picture, filter_len, filter, values_len, values
+    ):
+        return self.SetPictureFilter(
+            picture, filter_len, filter, values_len, values, is_checked=False
+        )
+
     def CreateAnimCursor(self, cid, cursors_len, cursors, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", cid))
         buf.write(xcffib.pack_list(cursors, ANIMCURSORELT))
         return self.send_request(31, buf, is_checked=is_checked)
 
+    def CreateAnimCursorChecked(self, cid, cursors_len, cursors):
+        return self.CreateAnimCursor(cid, cursors_len, cursors, is_checked=True)
+
+    def CreateAnimCursorUnchecked(self, cid, cursors_len, cursors):
+        return self.CreateAnimCursor(cid, cursors_len, cursors, is_checked=False)
+
     def AddTraps(self, picture, x_off, y_off, traps_len, traps, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIhh", picture, x_off, y_off))
         buf.write(xcffib.pack_list(traps, TRAP))
         return self.send_request(32, buf, is_checked=is_checked)
 
+    def AddTrapsChecked(self, picture, x_off, y_off, traps_len, traps):
+        return self.AddTraps(picture, x_off, y_off, traps_len, traps, is_checked=True)
+
+    def AddTrapsUnchecked(self, picture, x_off, y_off, traps_len, traps):
+        return self.AddTraps(picture, x_off, y_off, traps_len, traps, is_checked=False)
+
     def CreateSolidFill(self, picture, color, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", picture))
@@ -1278,6 +1730,12 @@ class renderExtension(xcffib.Extension):
         )
         return self.send_request(33, buf, is_checked=is_checked)
 
+    def CreateSolidFillChecked(self, picture, color):
+        return self.CreateSolidFill(picture, color, is_checked=True)
+
+    def CreateSolidFillUnchecked(self, picture, color):
+        return self.CreateSolidFill(picture, color, is_checked=False)
+
     def CreateLinearGradient(
         self, picture, p1, p2, num_stops, stops, colors, is_checked=False
     ):
@@ -1290,6 +1748,16 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(colors, COLOR))
         return self.send_request(34, buf, is_checked=is_checked)
 
+    def CreateLinearGradientChecked(self, picture, p1, p2, num_stops, stops, colors):
+        return self.CreateLinearGradient(
+            picture, p1, p2, num_stops, stops, colors, is_checked=True
+        )
+
+    def CreateLinearGradientUnchecked(self, picture, p1, p2, num_stops, stops, colors):
+        return self.CreateLinearGradient(
+            picture, p1, p2, num_stops, stops, colors, is_checked=False
+        )
+
     def CreateRadialGradient(
         self,
         picture,
@@ -1321,6 +1789,52 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(colors, COLOR))
         return self.send_request(35, buf, is_checked=is_checked)
 
+    def CreateRadialGradientChecked(
+        self,
+        picture,
+        inner,
+        outer,
+        inner_radius,
+        outer_radius,
+        num_stops,
+        stops,
+        colors,
+    ):
+        return self.CreateRadialGradient(
+            picture,
+            inner,
+            outer,
+            inner_radius,
+            outer_radius,
+            num_stops,
+            stops,
+            colors,
+            is_checked=True,
+        )
+
+    def CreateRadialGradientUnchecked(
+        self,
+        picture,
+        inner,
+        outer,
+        inner_radius,
+        outer_radius,
+        num_stops,
+        stops,
+        colors,
+    ):
+        return self.CreateRadialGradient(
+            picture,
+            inner,
+            outer,
+            inner_radius,
+            outer_radius,
+            num_stops,
+            stops,
+            colors,
+            is_checked=False,
+        )
+
     def CreateConicalGradient(
         self, picture, center, angle, num_stops, stops, colors, is_checked=False
     ):
@@ -1337,5 +1851,19 @@ class renderExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(colors, COLOR))
         return self.send_request(36, buf, is_checked=is_checked)
 
+    def CreateConicalGradientChecked(
+        self, picture, center, angle, num_stops, stops, colors
+    ):
+        return self.CreateConicalGradient(
+            picture, center, angle, num_stops, stops, colors, is_checked=True
+        )
+
+    def CreateConicalGradientUnchecked(
+        self, picture, center, angle, num_stops, stops, colors
+    ):
+        return self.CreateConicalGradient(
+            picture, center, angle, num_stops, stops, colors, is_checked=False
+        )
+
 
 xcffib._add_ext(key, renderExtension, _events, _errors)
