@@ -329,11 +329,23 @@ class resExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2xBB", client_major, client_minor))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 
+    def QueryVersionChecked(self, client_major, client_minor):
+        return self.QueryVersion(client_major, client_minor, is_checked=True)
+
+    def QueryVersionUnchecked(self, client_major, client_minor):
+        return self.QueryVersion(client_major, client_minor, is_checked=False)
+
     def QueryClients(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(1, buf, QueryClientsCookie, is_checked=is_checked)
 
+    def QueryClientsChecked(self):
+        return self.QueryClients(is_checked=True)
+
+    def QueryClientsUnchecked(self):
+        return self.QueryClients(is_checked=False)
+
     def QueryClientResources(self, xid, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", xid))
@@ -341,6 +353,12 @@ class resExtension(xcffib.Extension):
             2, buf, QueryClientResourcesCookie, is_checked=is_checked
         )
 
+    def QueryClientResourcesChecked(self, xid):
+        return self.QueryClientResources(xid, is_checked=True)
+
+    def QueryClientResourcesUnchecked(self, xid):
+        return self.QueryClientResources(xid, is_checked=False)
+
     def QueryClientPixmapBytes(self, xid, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", xid))
@@ -348,12 +366,24 @@ class resExtension(xcffib.Extension):
             3, buf, QueryClientPixmapBytesCookie, is_checked=is_checked
         )
 
+    def QueryClientPixmapBytesChecked(self, xid):
+        return self.QueryClientPixmapBytes(xid, is_checked=True)
+
+    def QueryClientPixmapBytesUnchecked(self, xid):
+        return self.QueryClientPixmapBytes(xid, is_checked=False)
+
     def QueryClientIds(self, num_specs, specs, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", num_specs))
         buf.write(xcffib.pack_list(specs, ClientIdSpec))
         return self.send_request(4, buf, QueryClientIdsCookie, is_checked=is_checked)
 
+    def QueryClientIdsChecked(self, num_specs, specs):
+        return self.QueryClientIds(num_specs, specs, is_checked=True)
+
+    def QueryClientIdsUnchecked(self, num_specs, specs):
+        return self.QueryClientIds(num_specs, specs, is_checked=False)
+
     def QueryResourceBytes(self, client, num_specs, specs, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", client, num_specs))
@@ -362,5 +392,11 @@ class resExtension(xcffib.Extension):
             5, buf, QueryResourceBytesCookie, is_checked=is_checked
         )
 
+    def QueryResourceBytesChecked(self, client, num_specs, specs):
+        return self.QueryResourceBytes(client, num_specs, specs, is_checked=True)
+
+    def QueryResourceBytesUnchecked(self, client, num_specs, specs):
+        return self.QueryResourceBytes(client, num_specs, specs, is_checked=False)
+
 
 xcffib._add_ext(key, resExtension, _events, _errors)
