@@ -41,7 +41,7 @@ class NotifyEvent(xcffib.Event):
             self.extents_height,
             self.server_time,
             self.shaped,
-        ) = unpacker.unpack("xB2xIhhHHIB11x")
+        ) = unpacker.unpack("=xB2xIhhHHIB11x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -100,7 +100,7 @@ class QueryVersionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.major_version, self.minor_version = unpacker.unpack("xx2x4xHH")
+        self.major_version, self.minor_version = unpacker.unpack("=xx2x4xHH")
         self.bufsize = unpacker.offset - base
 
 
@@ -127,7 +127,7 @@ class QueryExtentsReply(xcffib.Reply):
             self.clip_shape_extents_y,
             self.clip_shape_extents_width,
             self.clip_shape_extents_height,
-        ) = unpacker.unpack("xx2x4xBB2xhhHHhhHH")
+        ) = unpacker.unpack("=xx2x4xBB2xhhHHhhHH")
         self.bufsize = unpacker.offset - base
 
 
@@ -143,7 +143,7 @@ class InputSelectedReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.enabled,) = unpacker.unpack("xB2x4x")
+        (self.enabled,) = unpacker.unpack("=xB2x4x")
         self.bufsize = unpacker.offset - base
 
 
@@ -159,7 +159,7 @@ class GetRectanglesReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.ordering, self.rectangles_len = unpacker.unpack("xB2x4xI20x")
+        self.ordering, self.rectangles_len = unpacker.unpack("=xB2x4xI20x")
         self.rectangles = xcffib.List(unpacker, xproto.RECTANGLE, self.rectangles_len)
         self.bufsize = unpacker.offset - base
 
@@ -174,6 +174,12 @@ class shapeExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2x"))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 
+    def QueryVersionChecked(self):
+        return self.QueryVersion(is_checked=True)
+
+    def QueryVersionUnchecked(self):
+        return self.QueryVersion(is_checked=False)
+
     def Rectangles(
         self,
         operation,
@@ -201,6 +207,52 @@ class shapeExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(rectangles, xproto.RECTANGLE))
         return self.send_request(1, buf, is_checked=is_checked)
 
+    def RectanglesChecked(
+        self,
+        operation,
+        destination_kind,
+        ordering,
+        destination_window,
+        x_offset,
+        y_offset,
+        rectangles_len,
+        rectangles,
+    ):
+        return self.Rectangles(
+            operation,
+            destination_kind,
+            ordering,
+            destination_window,
+            x_offset,
+            y_offset,
+            rectangles_len,
+            rectangles,
+            is_checked=True,
+        )
+
+    def RectanglesUnchecked(
+        self,
+        operation,
+        destination_kind,
+        ordering,
+        destination_window,
+        x_offset,
+        y_offset,
+        rectangles_len,
+        rectangles,
+    ):
+        return self.Rectangles(
+            operation,
+            destination_kind,
+            ordering,
+            destination_window,
+            x_offset,
+            y_offset,
+            rectangles_len,
+            rectangles,
+            is_checked=False,
+        )
+
     def Mask(
         self,
         operation,
@@ -225,6 +277,44 @@ class shapeExtension(xcffib.Extension):
         )
         return self.send_request(2, buf, is_checked=is_checked)
 
+    def MaskChecked(
+        self,
+        operation,
+        destination_kind,
+        destination_window,
+        x_offset,
+        y_offset,
+        source_bitmap,
+    ):
+        return self.Mask(
+            operation,
+            destination_kind,
+            destination_window,
+            x_offset,
+            y_offset,
+            source_bitmap,
+            is_checked=True,
+        )
+
+    def MaskUnchecked(
+        self,
+        operation,
+        destination_kind,
+        destination_window,
+        x_offset,
+        y_offset,
+        source_bitmap,
+    ):
+        return self.Mask(
+            operation,
+            destination_kind,
+            destination_window,
+            x_offset,
+            y_offset,
+            source_bitmap,
+            is_checked=False,
+        )
+
     def Combine(
         self,
         operation,
@@ -251,6 +341,48 @@ class shapeExtension(xcffib.Extension):
         )
         return self.send_request(3, buf, is_checked=is_checked)
 
+    def CombineChecked(
+        self,
+        operation,
+        destination_kind,
+        source_kind,
+        destination_window,
+        x_offset,
+        y_offset,
+        source_window,
+    ):
+        return self.Combine(
+            operation,
+            destination_kind,
+            source_kind,
+            destination_window,
+            x_offset,
+            y_offset,
+            source_window,
+            is_checked=True,
+        )
+
+    def CombineUnchecked(
+        self,
+        operation,
+        destination_kind,
+        source_kind,
+        destination_window,
+        x_offset,
+        y_offset,
+        source_window,
+    ):
+        return self.Combine(
+            operation,
+            destination_kind,
+            source_kind,
+            destination_window,
+            x_offset,
+            y_offset,
+            source_window,
+            is_checked=False,
+        )
+
     def Offset(
         self, destination_kind, destination_window, x_offset, y_offset, is_checked=False
     ):
@@ -262,25 +394,59 @@ class shapeExtension(xcffib.Extension):
         )
         return self.send_request(4, buf, is_checked=is_checked)
 
+    def OffsetChecked(self, destination_kind, destination_window, x_offset, y_offset):
+        return self.Offset(
+            destination_kind, destination_window, x_offset, y_offset, is_checked=True
+        )
+
+    def OffsetUnchecked(self, destination_kind, destination_window, x_offset, y_offset):
+        return self.Offset(
+            destination_kind, destination_window, x_offset, y_offset, is_checked=False
+        )
+
     def QueryExtents(self, destination_window, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", destination_window))
         return self.send_request(5, buf, QueryExtentsCookie, is_checked=is_checked)
 
+    def QueryExtentsChecked(self, destination_window):
+        return self.QueryExtents(destination_window, is_checked=True)
+
+    def QueryExtentsUnchecked(self, destination_window):
+        return self.QueryExtents(destination_window, is_checked=False)
+
     def SelectInput(self, destination_window, enable, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIB3x", destination_window, enable))
         return self.send_request(6, buf, is_checked=is_checked)
 
+    def SelectInputChecked(self, destination_window, enable):
+        return self.SelectInput(destination_window, enable, is_checked=True)
+
+    def SelectInputUnchecked(self, destination_window, enable):
+        return self.SelectInput(destination_window, enable, is_checked=False)
+
     def InputSelected(self, destination_window, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", destination_window))
         return self.send_request(7, buf, InputSelectedCookie, is_checked=is_checked)
 
+    def InputSelectedChecked(self, destination_window):
+        return self.InputSelected(destination_window, is_checked=True)
+
+    def InputSelectedUnchecked(self, destination_window):
+        return self.InputSelected(destination_window, is_checked=False)
+
     def GetRectangles(self, window, source_kind, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIB3x", window, source_kind))
         return self.send_request(8, buf, GetRectanglesCookie, is_checked=is_checked)
 
+    def GetRectanglesChecked(self, window, source_kind):
+        return self.GetRectangles(window, source_kind, is_checked=True)
+
+    def GetRectanglesUnchecked(self, window, source_kind):
+        return self.GetRectangles(window, source_kind, is_checked=False)
+
 
 xcffib._add_ext(key, shapeExtension, _events, _errors)
