@@ -45,7 +45,7 @@ class INT64(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.hi, self.lo = unpacker.unpack("iI")
+        self.hi, self.lo = unpacker.unpack("=iI")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -71,9 +71,9 @@ class SYSTEMCOUNTER(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        (self.counter,) = unpacker.unpack("I")
+        (self.counter,) = unpacker.unpack("=I")
         self.resolution = INT64(unpacker)
-        (self.name_len,) = unpacker.unpack("H")
+        (self.name_len,) = unpacker.unpack("=H")
         unpacker.pad("c")
         self.name = xcffib.List(unpacker, "c", self.name_len)
         self.bufsize = unpacker.offset - base
@@ -113,9 +113,9 @@ class TRIGGER(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.counter, self.wait_type = unpacker.unpack("II")
+        self.counter, self.wait_type = unpacker.unpack("=II")
         self.wait_value = INT64(unpacker)
-        (self.test_type,) = unpacker.unpack("I")
+        (self.test_type,) = unpacker.unpack("=I")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -183,7 +183,7 @@ class CounterError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_counter, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB"
+            "=xx2xIHB"
         )
         self.bufsize = unpacker.offset - base
 
@@ -211,7 +211,7 @@ class AlarmError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_alarm, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB"
+            "=xx2xIHB"
         )
         self.bufsize = unpacker.offset - base
 
@@ -236,7 +236,7 @@ class InitializeReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.major_version, self.minor_version = unpacker.unpack("xx2x4xBB22x")
+        self.major_version, self.minor_version = unpacker.unpack("=xx2x4xBB22x")
         self.bufsize = unpacker.offset - base
 
 
@@ -252,7 +252,7 @@ class ListSystemCountersReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.counters_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.counters_len,) = unpacker.unpack("=xx2x4xI20x")
         self.counters = xcffib.List(unpacker, SYSTEMCOUNTER, self.counters_len)
         self.bufsize = unpacker.offset - base
 
@@ -269,7 +269,7 @@ class QueryCounterReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x")
+        unpacker.unpack("=xx2x4x")
         self.counter_value = INT64(unpacker)
         self.bufsize = unpacker.offset - base
 
@@ -286,11 +286,11 @@ class QueryAlarmReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x")
+        unpacker.unpack("=xx2x4x")
         self.trigger = TRIGGER(unpacker)
         unpacker.pad(INT64)
         self.delta = INT64(unpacker)
-        self.events, self.state = unpacker.unpack("BB2x")
+        self.events, self.state = unpacker.unpack("=BB2x")
         self.bufsize = unpacker.offset - base
 
 
@@ -306,7 +306,7 @@ class GetPriorityReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.priority,) = unpacker.unpack("xx2x4xi")
+        (self.priority,) = unpacker.unpack("=xx2x4xi")
         self.bufsize = unpacker.offset - base
 
 
@@ -322,7 +322,7 @@ class QueryFenceReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.triggered,) = unpacker.unpack("xx2x4xB23x")
+        (self.triggered,) = unpacker.unpack("=xx2x4xB23x")
         self.bufsize = unpacker.offset - base
 
 
@@ -338,11 +338,11 @@ class CounterNotifyEvent(xcffib.Event):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Event.__init__(self, unpacker)
         base = unpacker.offset
-        self.kind, self.counter = unpacker.unpack("xB2xI")
+        self.kind, self.counter = unpacker.unpack("=xB2xI")
         self.wait_value = INT64(unpacker)
         unpacker.pad(INT64)
         self.counter_value = INT64(unpacker)
-        self.timestamp, self.count, self.destroyed = unpacker.unpack("IHBx")
+        self.timestamp, self.count, self.destroyed = unpacker.unpack("=IHBx")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -398,11 +398,11 @@ class AlarmNotifyEvent(xcffib.Event):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Event.__init__(self, unpacker)
         base = unpacker.offset
-        self.kind, self.alarm = unpacker.unpack("xB2xI")
+        self.kind, self.alarm = unpacker.unpack("=xB2xI")
         self.counter_value = INT64(unpacker)
         unpacker.pad(INT64)
         self.alarm_value = INT64(unpacker)
-        self.timestamp, self.state = unpacker.unpack("IB3x")
+        self.timestamp, self.state = unpacker.unpack("=IB3x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -452,6 +452,16 @@ class syncExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2xBB", desired_major_version, desired_minor_version))
         return self.send_request(0, buf, InitializeCookie, is_checked=is_checked)
 
+    def InitializeChecked(self, desired_major_version, desired_minor_version):
+        return self.Initialize(
+            desired_major_version, desired_minor_version, is_checked=True
+        )
+
+    def InitializeUnchecked(self, desired_major_version, desired_minor_version):
+        return self.Initialize(
+            desired_major_version, desired_minor_version, is_checked=False
+        )
+
     def ListSystemCounters(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
@@ -459,6 +469,12 @@ class syncExtension(xcffib.Extension):
             1, buf, ListSystemCountersCookie, is_checked=is_checked
         )
 
+    def ListSystemCountersChecked(self):
+        return self.ListSystemCounters(is_checked=True)
+
+    def ListSystemCountersUnchecked(self):
+        return self.ListSystemCounters(is_checked=False)
+
     def CreateCounter(self, id, initial_value, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", id))
@@ -469,22 +485,46 @@ class syncExtension(xcffib.Extension):
         )
         return self.send_request(2, buf, is_checked=is_checked)
 
+    def CreateCounterChecked(self, id, initial_value):
+        return self.CreateCounter(id, initial_value, is_checked=True)
+
+    def CreateCounterUnchecked(self, id, initial_value):
+        return self.CreateCounter(id, initial_value, is_checked=False)
+
     def DestroyCounter(self, counter, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", counter))
         return self.send_request(6, buf, is_checked=is_checked)
 
+    def DestroyCounterChecked(self, counter):
+        return self.DestroyCounter(counter, is_checked=True)
+
+    def DestroyCounterUnchecked(self, counter):
+        return self.DestroyCounter(counter, is_checked=False)
+
     def QueryCounter(self, counter, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", counter))
         return self.send_request(5, buf, QueryCounterCookie, is_checked=is_checked)
 
+    def QueryCounterChecked(self, counter):
+        return self.QueryCounter(counter, is_checked=True)
+
+    def QueryCounterUnchecked(self, counter):
+        return self.QueryCounter(counter, is_checked=False)
+
     def Await(self, wait_list_len, wait_list, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         buf.write(xcffib.pack_list(wait_list, WAITCONDITION))
         return self.send_request(7, buf, is_checked=is_checked)
 
+    def AwaitChecked(self, wait_list_len, wait_list):
+        return self.Await(wait_list_len, wait_list, is_checked=True)
+
+    def AwaitUnchecked(self, wait_list_len, wait_list):
+        return self.Await(wait_list_len, wait_list, is_checked=False)
+
     def ChangeCounter(self, counter, amount, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", counter))
@@ -495,6 +535,12 @@ class syncExtension(xcffib.Extension):
         )
         return self.send_request(4, buf, is_checked=is_checked)
 
+    def ChangeCounterChecked(self, counter, amount):
+        return self.ChangeCounter(counter, amount, is_checked=True)
+
+    def ChangeCounterUnchecked(self, counter, amount):
+        return self.ChangeCounter(counter, amount, is_checked=False)
+
     def SetCounter(self, counter, value, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", counter))
@@ -503,6 +549,12 @@ class syncExtension(xcffib.Extension):
         )
         return self.send_request(3, buf, is_checked=is_checked)
 
+    def SetCounterChecked(self, counter, value):
+        return self.SetCounter(counter, value, is_checked=True)
+
+    def SetCounterUnchecked(self, counter, value):
+        return self.SetCounter(counter, value, is_checked=False)
+
     def CreateAlarm(self, id, value_mask, value_list, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", id, value_mask))
@@ -534,6 +586,12 @@ class syncExtension(xcffib.Extension):
             buf.write(struct.pack("=I", events))
         return self.send_request(8, buf, is_checked=is_checked)
 
+    def CreateAlarmChecked(self, id, value_mask, value_list):
+        return self.CreateAlarm(id, value_mask, value_list, is_checked=True)
+
+    def CreateAlarmUnchecked(self, id, value_mask, value_list):
+        return self.CreateAlarm(id, value_mask, value_list, is_checked=False)
+
     def ChangeAlarm(self, id, value_mask, value_list, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", id, value_mask))
@@ -565,56 +623,122 @@ class syncExtension(xcffib.Extension):
             buf.write(struct.pack("=I", events))
         return self.send_request(9, buf, is_checked=is_checked)
 
+    def ChangeAlarmChecked(self, id, value_mask, value_list):
+        return self.ChangeAlarm(id, value_mask, value_list, is_checked=True)
+
+    def ChangeAlarmUnchecked(self, id, value_mask, value_list):
+        return self.ChangeAlarm(id, value_mask, value_list, is_checked=False)
+
     def DestroyAlarm(self, alarm, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", alarm))
         return self.send_request(11, buf, is_checked=is_checked)
 
+    def DestroyAlarmChecked(self, alarm):
+        return self.DestroyAlarm(alarm, is_checked=True)
+
+    def DestroyAlarmUnchecked(self, alarm):
+        return self.DestroyAlarm(alarm, is_checked=False)
+
     def QueryAlarm(self, alarm, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", alarm))
         return self.send_request(10, buf, QueryAlarmCookie, is_checked=is_checked)
 
+    def QueryAlarmChecked(self, alarm):
+        return self.QueryAlarm(alarm, is_checked=True)
+
+    def QueryAlarmUnchecked(self, alarm):
+        return self.QueryAlarm(alarm, is_checked=False)
+
     def SetPriority(self, id, priority, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIi", id, priority))
         return self.send_request(12, buf, is_checked=is_checked)
 
+    def SetPriorityChecked(self, id, priority):
+        return self.SetPriority(id, priority, is_checked=True)
+
+    def SetPriorityUnchecked(self, id, priority):
+        return self.SetPriority(id, priority, is_checked=False)
+
     def GetPriority(self, id, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", id))
         return self.send_request(13, buf, GetPriorityCookie, is_checked=is_checked)
 
+    def GetPriorityChecked(self, id):
+        return self.GetPriority(id, is_checked=True)
+
+    def GetPriorityUnchecked(self, id):
+        return self.GetPriority(id, is_checked=False)
+
     def CreateFence(self, drawable, fence, initially_triggered, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIB", drawable, fence, initially_triggered))
         return self.send_request(14, buf, is_checked=is_checked)
 
+    def CreateFenceChecked(self, drawable, fence, initially_triggered):
+        return self.CreateFence(drawable, fence, initially_triggered, is_checked=True)
+
+    def CreateFenceUnchecked(self, drawable, fence, initially_triggered):
+        return self.CreateFence(drawable, fence, initially_triggered, is_checked=False)
+
     def TriggerFence(self, fence, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", fence))
         return self.send_request(15, buf, is_checked=is_checked)
 
+    def TriggerFenceChecked(self, fence):
+        return self.TriggerFence(fence, is_checked=True)
+
+    def TriggerFenceUnchecked(self, fence):
+        return self.TriggerFence(fence, is_checked=False)
+
     def ResetFence(self, fence, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", fence))
         return self.send_request(16, buf, is_checked=is_checked)
 
+    def ResetFenceChecked(self, fence):
+        return self.ResetFence(fence, is_checked=True)
+
+    def ResetFenceUnchecked(self, fence):
+        return self.ResetFence(fence, is_checked=False)
+
     def DestroyFence(self, fence, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", fence))
         return self.send_request(17, buf, is_checked=is_checked)
 
+    def DestroyFenceChecked(self, fence):
+        return self.DestroyFence(fence, is_checked=True)
+
+    def DestroyFenceUnchecked(self, fence):
+        return self.DestroyFence(fence, is_checked=False)
+
     def QueryFence(self, fence, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", fence))
         return self.send_request(18, buf, QueryFenceCookie, is_checked=is_checked)
 
+    def QueryFenceChecked(self, fence):
+        return self.QueryFence(fence, is_checked=True)
+
+    def QueryFenceUnchecked(self, fence):
+        return self.QueryFence(fence, is_checked=False)
+
     def AwaitFence(self, fence_list_len, fence_list, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         buf.write(xcffib.pack_list(fence_list, "I"))
         return self.send_request(19, buf, is_checked=is_checked)
 
+    def AwaitFenceChecked(self, fence_list_len, fence_list):
+        return self.AwaitFence(fence_list_len, fence_list, is_checked=True)
+
+    def AwaitFenceUnchecked(self, fence_list_len, fence_list):
+        return self.AwaitFence(fence_list_len, fence_list, is_checked=False)
+
 
 xcffib._add_ext(key, syncExtension, _events, _errors)
