@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 0
@@ -10,7 +9,6 @@ _events = {}
 _errors = {}
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -20,17 +18,15 @@ class QueryVersionReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.server_major_version, self.server_minor_version = unpacker.unpack(
-            "xx2x4xHH20x"
+            "=xx2x4xHH20x"
         )
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class StartReply(xcffib.Reply):
     xge = False
 
@@ -39,16 +35,14 @@ class StartReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x24x")
+        unpacker.unpack("=xx2x4x24x")
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class StartCookie(xcffib.Cookie):
     reply_type = StartReply
 
 
-@dataclass(init=False)
 class EndReply(xcffib.Reply):
     xge = False
 
@@ -57,22 +51,19 @@ class EndReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x24x")
+        unpacker.unpack("=xx2x4x24x")
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class EndCookie(xcffib.Cookie):
     reply_type = EndReply
 
 
-@dataclass(init=False)
 class Datatype:
     Unmodified = 0
     Modified = 1
 
 
-@dataclass(init=False)
 class Event(xcffib.Struct):
     xge = False
 
@@ -81,7 +72,7 @@ class Event(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("32x")
+        unpacker.unpack("=32x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -92,7 +83,6 @@ class Event(xcffib.Struct):
     fixed_size = 32
 
 
-@dataclass(init=False)
 class SendReply(xcffib.Reply):
     xge = False
 
@@ -101,16 +91,14 @@ class SendReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x24x")
+        unpacker.unpack("=xx2x4x24x")
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class SendCookie(xcffib.Cookie):
     reply_type = SendReply
 
 
-@dataclass(init=False)
 class SelectInputReply(xcffib.Reply):
     xge = False
 
@@ -119,32 +107,52 @@ class SelectInputReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x24x")
+        unpacker.unpack("=xx2x4x24x")
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class SelectInputCookie(xcffib.Cookie):
     reply_type = SelectInputReply
 
 
-@dataclass(init=False)
 class xevieExtension(xcffib.Extension):
     def QueryVersion(self, client_major_version, client_minor_version, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xHH", client_major_version, client_minor_version))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 
+    def QueryVersionChecked(self, client_major_version, client_minor_version):
+        return self.QueryVersion(
+            client_major_version, client_minor_version, is_checked=True
+        )
+
+    def QueryVersionUnchecked(self, client_major_version, client_minor_version):
+        return self.QueryVersion(
+            client_major_version, client_minor_version, is_checked=False
+        )
+
     def Start(self, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", screen))
         return self.send_request(1, buf, StartCookie, is_checked=is_checked)
 
+    def StartChecked(self, screen):
+        return self.Start(screen, is_checked=True)
+
+    def StartUnchecked(self, screen):
+        return self.Start(screen, is_checked=False)
+
     def End(self, cmap, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", cmap))
         return self.send_request(2, buf, EndCookie, is_checked=is_checked)
 
+    def EndChecked(self, cmap):
+        return self.End(cmap, is_checked=True)
+
+    def EndUnchecked(self, cmap):
+        return self.End(cmap, is_checked=False)
+
     def Send(self, event, data_type, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
@@ -159,10 +167,22 @@ class xevieExtension(xcffib.Extension):
         )
         return self.send_request(3, buf, SendCookie, is_checked=is_checked)
 
+    def SendChecked(self, event, data_type):
+        return self.Send(event, data_type, is_checked=True)
+
+    def SendUnchecked(self, event, data_type):
+        return self.Send(event, data_type, is_checked=False)
+
     def SelectInput(self, event_mask, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", event_mask))
         return self.send_request(4, buf, SelectInputCookie, is_checked=is_checked)
 
+    def SelectInputChecked(self, event_mask):
+        return self.SelectInput(event_mask, is_checked=True)
+
+    def SelectInputUnchecked(self, event_mask):
+        return self.SelectInput(event_mask, is_checked=False)
+
 
 xcffib._add_ext(key, xevieExtension, _events, _errors)
