@@ -224,6 +224,12 @@ class xf86driExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2x"))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 
+    def QueryVersionChecked(self):
+        return self.QueryVersion(is_checked=True)
+
+    def QueryVersionUnchecked(self):
+        return self.QueryVersion(is_checked=False)
+
     def QueryDirectRenderingCapable(self, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", screen))
@@ -231,16 +237,34 @@ class xf86driExtension(xcffib.Extension):
             1, buf, QueryDirectRenderingCapableCookie, is_checked=is_checked
         )
 
+    def QueryDirectRenderingCapableChecked(self, screen):
+        return self.QueryDirectRenderingCapable(screen, is_checked=True)
+
+    def QueryDirectRenderingCapableUnchecked(self, screen):
+        return self.QueryDirectRenderingCapable(screen, is_checked=False)
+
     def OpenConnection(self, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", screen))
         return self.send_request(2, buf, OpenConnectionCookie, is_checked=is_checked)
 
+    def OpenConnectionChecked(self, screen):
+        return self.OpenConnection(screen, is_checked=True)
+
+    def OpenConnectionUnchecked(self, screen):
+        return self.OpenConnection(screen, is_checked=False)
+
     def CloseConnection(self, screen, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", screen))
         return self.send_request(3, buf, is_checked=is_checked)
 
+    def CloseConnectionChecked(self, screen):
+        return self.CloseConnection(screen, is_checked=True)
+
+    def CloseConnectionUnchecked(self, screen):
+        return self.CloseConnection(screen, is_checked=False)
+
     def GetClientDriverName(self, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", screen))
@@ -248,40 +272,88 @@ class xf86driExtension(xcffib.Extension):
             4, buf, GetClientDriverNameCookie, is_checked=is_checked
         )
 
+    def GetClientDriverNameChecked(self, screen):
+        return self.GetClientDriverName(screen, is_checked=True)
+
+    def GetClientDriverNameUnchecked(self, screen):
+        return self.GetClientDriverName(screen, is_checked=False)
+
     def CreateContext(self, screen, visual, context, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIII", screen, visual, context))
         return self.send_request(5, buf, CreateContextCookie, is_checked=is_checked)
 
+    def CreateContextChecked(self, screen, visual, context):
+        return self.CreateContext(screen, visual, context, is_checked=True)
+
+    def CreateContextUnchecked(self, screen, visual, context):
+        return self.CreateContext(screen, visual, context, is_checked=False)
+
     def DestroyContext(self, screen, context, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", screen, context))
         return self.send_request(6, buf, is_checked=is_checked)
 
+    def DestroyContextChecked(self, screen, context):
+        return self.DestroyContext(screen, context, is_checked=True)
+
+    def DestroyContextUnchecked(self, screen, context):
+        return self.DestroyContext(screen, context, is_checked=False)
+
     def CreateDrawable(self, screen, drawable, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", screen, drawable))
         return self.send_request(7, buf, CreateDrawableCookie, is_checked=is_checked)
 
+    def CreateDrawableChecked(self, screen, drawable):
+        return self.CreateDrawable(screen, drawable, is_checked=True)
+
+    def CreateDrawableUnchecked(self, screen, drawable):
+        return self.CreateDrawable(screen, drawable, is_checked=False)
+
     def DestroyDrawable(self, screen, drawable, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", screen, drawable))
         return self.send_request(8, buf, is_checked=is_checked)
 
+    def DestroyDrawableChecked(self, screen, drawable):
+        return self.DestroyDrawable(screen, drawable, is_checked=True)
+
+    def DestroyDrawableUnchecked(self, screen, drawable):
+        return self.DestroyDrawable(screen, drawable, is_checked=False)
+
     def GetDrawableInfo(self, screen, drawable, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", screen, drawable))
         return self.send_request(9, buf, GetDrawableInfoCookie, is_checked=is_checked)
 
+    def GetDrawableInfoChecked(self, screen, drawable):
+        return self.GetDrawableInfo(screen, drawable, is_checked=True)
+
+    def GetDrawableInfoUnchecked(self, screen, drawable):
+        return self.GetDrawableInfo(screen, drawable, is_checked=False)
+
     def GetDeviceInfo(self, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", screen))
         return self.send_request(10, buf, GetDeviceInfoCookie, is_checked=is_checked)
 
+    def GetDeviceInfoChecked(self, screen):
+        return self.GetDeviceInfo(screen, is_checked=True)
+
+    def GetDeviceInfoUnchecked(self, screen):
+        return self.GetDeviceInfo(screen, is_checked=False)
+
     def AuthConnection(self, screen, magic, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", screen, magic))
         return self.send_request(11, buf, AuthConnectionCookie, is_checked=is_checked)
 
+    def AuthConnectionChecked(self, screen, magic):
+        return self.AuthConnection(screen, magic, is_checked=True)
+
+    def AuthConnectionUnchecked(self, screen, magic):
+        return self.AuthConnection(screen, magic, is_checked=False)
+
 
 xcffib._add_ext(key, xf86driExtension, _events, _errors)
