@@ -483,11 +483,23 @@ class xf86vidmodeExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2x"))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 
+    def QueryVersionChecked(self):
+        return self.QueryVersion(is_checked=True)
+
+    def QueryVersionUnchecked(self):
+        return self.QueryVersion(is_checked=False)
+
     def GetModeLine(self, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(1, buf, GetModeLineCookie, is_checked=is_checked)
 
+    def GetModeLineChecked(self, screen):
+        return self.GetModeLine(screen, is_checked=True)
+
+    def GetModeLineUnchecked(self, screen):
+        return self.GetModeLine(screen, is_checked=False)
+
     def ModModeLine(
         self,
         screen,
@@ -526,26 +538,116 @@ class xf86vidmodeExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(private, "B"))
         return self.send_request(2, buf, is_checked=is_checked)
 
+    def ModModeLineChecked(
+        self,
+        screen,
+        hdisplay,
+        hsyncstart,
+        hsyncend,
+        htotal,
+        hskew,
+        vdisplay,
+        vsyncstart,
+        vsyncend,
+        vtotal,
+        flags,
+        privsize,
+        private,
+    ):
+        return self.ModModeLine(
+            screen,
+            hdisplay,
+            hsyncstart,
+            hsyncend,
+            htotal,
+            hskew,
+            vdisplay,
+            vsyncstart,
+            vsyncend,
+            vtotal,
+            flags,
+            privsize,
+            private,
+            is_checked=True,
+        )
+
+    def ModModeLineUnchecked(
+        self,
+        screen,
+        hdisplay,
+        hsyncstart,
+        hsyncend,
+        htotal,
+        hskew,
+        vdisplay,
+        vsyncstart,
+        vsyncend,
+        vtotal,
+        flags,
+        privsize,
+        private,
+    ):
+        return self.ModModeLine(
+            screen,
+            hdisplay,
+            hsyncstart,
+            hsyncend,
+            htotal,
+            hskew,
+            vdisplay,
+            vsyncstart,
+            vsyncend,
+            vtotal,
+            flags,
+            privsize,
+            private,
+            is_checked=False,
+        )
+
     def SwitchMode(self, screen, zoom, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xHH", screen, zoom))
         return self.send_request(3, buf, is_checked=is_checked)
 
+    def SwitchModeChecked(self, screen, zoom):
+        return self.SwitchMode(screen, zoom, is_checked=True)
+
+    def SwitchModeUnchecked(self, screen, zoom):
+        return self.SwitchMode(screen, zoom, is_checked=False)
+
     def GetMonitor(self, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(4, buf, GetMonitorCookie, is_checked=is_checked)
 
+    def GetMonitorChecked(self, screen):
+        return self.GetMonitor(screen, is_checked=True)
+
+    def GetMonitorUnchecked(self, screen):
+        return self.GetMonitor(screen, is_checked=False)
+
     def LockModeSwitch(self, screen, lock, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xHH", screen, lock))
         return self.send_request(5, buf, is_checked=is_checked)
 
+    def LockModeSwitchChecked(self, screen, lock):
+        return self.LockModeSwitch(screen, lock, is_checked=True)
+
+    def LockModeSwitchUnchecked(self, screen, lock):
+        return self.LockModeSwitch(screen, lock, is_checked=False)
+
     def GetAllModeLines(self, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(6, buf, GetAllModeLinesCookie, is_checked=is_checked)
 
+    def GetAllModeLinesChecked(self, screen):
+        return self.GetAllModeLines(screen, is_checked=True)
+
+    def GetAllModeLinesUnchecked(self, screen):
+        return self.GetAllModeLines(screen, is_checked=False)
+
     def AddModeLine(
         self,
         screen,
@@ -608,6 +710,120 @@ class xf86vidmodeExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(private, "B"))
         return self.send_request(7, buf, is_checked=is_checked)
 
+    def AddModeLineChecked(
+        self,
+        screen,
+        dotclock,
+        hdisplay,
+        hsyncstart,
+        hsyncend,
+        htotal,
+        hskew,
+        vdisplay,
+        vsyncstart,
+        vsyncend,
+        vtotal,
+        flags,
+        privsize,
+        after_dotclock,
+        after_hdisplay,
+        after_hsyncstart,
+        after_hsyncend,
+        after_htotal,
+        after_hskew,
+        after_vdisplay,
+        after_vsyncstart,
+        after_vsyncend,
+        after_vtotal,
+        after_flags,
+        private,
+    ):
+        return self.AddModeLine(
+            screen,
+            dotclock,
+            hdisplay,
+            hsyncstart,
+            hsyncend,
+            htotal,
+            hskew,
+            vdisplay,
+            vsyncstart,
+            vsyncend,
+            vtotal,
+            flags,
+            privsize,
+            after_dotclock,
+            after_hdisplay,
+            after_hsyncstart,
+            after_hsyncend,
+            after_htotal,
+            after_hskew,
+            after_vdisplay,
+            after_vsyncstart,
+            after_vsyncend,
+            after_vtotal,
+            after_flags,
+            private,
+            is_checked=True,
+        )
+
+    def AddModeLineUnchecked(
+        self,
+        screen,
+        dotclock,
+        hdisplay,
+        hsyncstart,
+        hsyncend,
+        htotal,
+        hskew,
+        vdisplay,
+        vsyncstart,
+        vsyncend,
+        vtotal,
+        flags,
+        privsize,
+        after_dotclock,
+        after_hdisplay,
+        after_hsyncstart,
+        after_hsyncend,
+        after_htotal,
+        after_hskew,
+        after_vdisplay,
+        after_vsyncstart,
+        after_vsyncend,
+        after_vtotal,
+        after_flags,
+        private,
+    ):
+        return self.AddModeLine(
+            screen,
+            dotclock,
+            hdisplay,
+            hsyncstart,
+            hsyncend,
+            htotal,
+            hskew,
+            vdisplay,
+            vsyncstart,
+            vsyncend,
+            vtotal,
+            flags,
+            privsize,
+            after_dotclock,
+            after_hdisplay,
+            after_hsyncstart,
+            after_hsyncend,
+            after_htotal,
+            after_hskew,
+            after_vdisplay,
+            after_vsyncstart,
+            after_vsyncend,
+            after_vtotal,
+            after_flags,
+            private,
+            is_checked=False,
+        )
+
     def DeleteModeLine(
         self,
         screen,
@@ -648,6 +864,76 @@ class xf86vidmodeExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(private, "B"))
         return self.send_request(8, buf, is_checked=is_checked)
 
+    def DeleteModeLineChecked(
+        self,
+        screen,
+        dotclock,
+        hdisplay,
+        hsyncstart,
+        hsyncend,
+        htotal,
+        hskew,
+        vdisplay,
+        vsyncstart,
+        vsyncend,
+        vtotal,
+        flags,
+        privsize,
+        private,
+    ):
+        return self.DeleteModeLine(
+            screen,
+            dotclock,
+            hdisplay,
+            hsyncstart,
+            hsyncend,
+            htotal,
+            hskew,
+            vdisplay,
+            vsyncstart,
+            vsyncend,
+            vtotal,
+            flags,
+            privsize,
+            private,
+            is_checked=True,
+        )
+
+    def DeleteModeLineUnchecked(
+        self,
+        screen,
+        dotclock,
+        hdisplay,
+        hsyncstart,
+        hsyncend,
+        htotal,
+        hskew,
+        vdisplay,
+        vsyncstart,
+        vsyncend,
+        vtotal,
+        flags,
+        privsize,
+        private,
+    ):
+        return self.DeleteModeLine(
+            screen,
+            dotclock,
+            hdisplay,
+            hsyncstart,
+            hsyncend,
+            htotal,
+            hskew,
+            vdisplay,
+            vsyncstart,
+            vsyncend,
+            vtotal,
+            flags,
+            privsize,
+            private,
+            is_checked=False,
+        )
+
     def ValidateModeLine(
         self,
         screen,
@@ -688,6 +974,76 @@ class xf86vidmodeExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(private, "B"))
         return self.send_request(9, buf, ValidateModeLineCookie, is_checked=is_checked)
 
+    def ValidateModeLineChecked(
+        self,
+        screen,
+        dotclock,
+        hdisplay,
+        hsyncstart,
+        hsyncend,
+        htotal,
+        hskew,
+        vdisplay,
+        vsyncstart,
+        vsyncend,
+        vtotal,
+        flags,
+        privsize,
+        private,
+    ):
+        return self.ValidateModeLine(
+            screen,
+            dotclock,
+            hdisplay,
+            hsyncstart,
+            hsyncend,
+            htotal,
+            hskew,
+            vdisplay,
+            vsyncstart,
+            vsyncend,
+            vtotal,
+            flags,
+            privsize,
+            private,
+            is_checked=True,
+        )
+
+    def ValidateModeLineUnchecked(
+        self,
+        screen,
+        dotclock,
+        hdisplay,
+        hsyncstart,
+        hsyncend,
+        htotal,
+        hskew,
+        vdisplay,
+        vsyncstart,
+        vsyncend,
+        vtotal,
+        flags,
+        privsize,
+        private,
+    ):
+        return self.ValidateModeLine(
+            screen,
+            dotclock,
+            hdisplay,
+            hsyncstart,
+            hsyncend,
+            htotal,
+            hskew,
+            vdisplay,
+            vsyncstart,
+            vsyncend,
+            vtotal,
+            flags,
+            privsize,
+            private,
+            is_checked=False,
+        )
+
     def SwitchToMode(
         self,
         screen,
@@ -728,41 +1084,153 @@ class xf86vidmodeExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(private, "B"))
         return self.send_request(10, buf, is_checked=is_checked)
 
+    def SwitchToModeChecked(
+        self,
+        screen,
+        dotclock,
+        hdisplay,
+        hsyncstart,
+        hsyncend,
+        htotal,
+        hskew,
+        vdisplay,
+        vsyncstart,
+        vsyncend,
+        vtotal,
+        flags,
+        privsize,
+        private,
+    ):
+        return self.SwitchToMode(
+            screen,
+            dotclock,
+            hdisplay,
+            hsyncstart,
+            hsyncend,
+            htotal,
+            hskew,
+            vdisplay,
+            vsyncstart,
+            vsyncend,
+            vtotal,
+            flags,
+            privsize,
+            private,
+            is_checked=True,
+        )
+
+    def SwitchToModeUnchecked(
+        self,
+        screen,
+        dotclock,
+        hdisplay,
+        hsyncstart,
+        hsyncend,
+        htotal,
+        hskew,
+        vdisplay,
+        vsyncstart,
+        vsyncend,
+        vtotal,
+        flags,
+        privsize,
+        private,
+    ):
+        return self.SwitchToMode(
+            screen,
+            dotclock,
+            hdisplay,
+            hsyncstart,
+            hsyncend,
+            htotal,
+            hskew,
+            vdisplay,
+            vsyncstart,
+            vsyncend,
+            vtotal,
+            flags,
+            privsize,
+            private,
+            is_checked=False,
+        )
+
     def GetViewPort(self, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(11, buf, GetViewPortCookie, is_checked=is_checked)
 
+    def GetViewPortChecked(self, screen):
+        return self.GetViewPort(screen, is_checked=True)
+
+    def GetViewPortUnchecked(self, screen):
+        return self.GetViewPort(screen, is_checked=False)
+
     def SetViewPort(self, screen, x, y, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2xII", screen, x, y))
         return self.send_request(12, buf, is_checked=is_checked)
 
+    def SetViewPortChecked(self, screen, x, y):
+        return self.SetViewPort(screen, x, y, is_checked=True)
+
+    def SetViewPortUnchecked(self, screen, x, y):
+        return self.SetViewPort(screen, x, y, is_checked=False)
+
     def GetDotClocks(self, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(13, buf, GetDotClocksCookie, is_checked=is_checked)
 
+    def GetDotClocksChecked(self, screen):
+        return self.GetDotClocks(screen, is_checked=True)
+
+    def GetDotClocksUnchecked(self, screen):
+        return self.GetDotClocks(screen, is_checked=False)
+
     def SetClientVersion(self, major, minor, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xHH", major, minor))
         return self.send_request(14, buf, is_checked=is_checked)
 
+    def SetClientVersionChecked(self, major, minor):
+        return self.SetClientVersion(major, minor, is_checked=True)
+
+    def SetClientVersionUnchecked(self, major, minor):
+        return self.SetClientVersion(major, minor, is_checked=False)
+
     def SetGamma(self, screen, red, green, blue, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2xIII12x", screen, red, green, blue))
         return self.send_request(15, buf, is_checked=is_checked)
 
+    def SetGammaChecked(self, screen, red, green, blue):
+        return self.SetGamma(screen, red, green, blue, is_checked=True)
+
+    def SetGammaUnchecked(self, screen, red, green, blue):
+        return self.SetGamma(screen, red, green, blue, is_checked=False)
+
     def GetGamma(self, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH26x", screen))
         return self.send_request(16, buf, GetGammaCookie, is_checked=is_checked)
 
+    def GetGammaChecked(self, screen):
+        return self.GetGamma(screen, is_checked=True)
+
+    def GetGammaUnchecked(self, screen):
+        return self.GetGamma(screen, is_checked=False)
+
     def GetGammaRamp(self, screen, size, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xHH", screen, size))
         return self.send_request(17, buf, GetGammaRampCookie, is_checked=is_checked)
 
+    def GetGammaRampChecked(self, screen, size):
+        return self.GetGammaRamp(screen, size, is_checked=True)
+
+    def GetGammaRampUnchecked(self, screen, size):
+        return self.GetGammaRamp(screen, size, is_checked=False)
+
     def SetGammaRamp(self, screen, size, red, green, blue, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xHH", screen, size))
@@ -771,15 +1239,33 @@ class xf86vidmodeExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(blue, "H"))
         return self.send_request(18, buf, is_checked=is_checked)
 
+    def SetGammaRampChecked(self, screen, size, red, green, blue):
+        return self.SetGammaRamp(screen, size, red, green, blue, is_checked=True)
+
+    def SetGammaRampUnchecked(self, screen, size, red, green, blue):
+        return self.SetGammaRamp(screen, size, red, green, blue, is_checked=False)
+
     def GetGammaRampSize(self, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(19, buf, GetGammaRampSizeCookie, is_checked=is_checked)
 
+    def GetGammaRampSizeChecked(self, screen):
+        return self.GetGammaRampSize(screen, is_checked=True)
+
+    def GetGammaRampSizeUnchecked(self, screen):
+        return self.GetGammaRampSize(screen, is_checked=False)
+
     def GetPermissions(self, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(20, buf, GetPermissionsCookie, is_checked=is_checked)
 
+    def GetPermissionsChecked(self, screen):
+        return self.GetPermissions(screen, is_checked=True)
+
+    def GetPermissionsUnchecked(self, screen):
+        return self.GetPermissions(screen, is_checked=False)
+
 
 xcffib._add_ext(key, xf86vidmodeExtension, _events, _errors)
