@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 1
@@ -11,7 +10,6 @@ _errors = {}
 from . import xproto
 
 
-@dataclass(init=False)
 class ScreenInfo(xcffib.Struct):
     xge = False
 
@@ -20,7 +18,7 @@ class ScreenInfo(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.x_org, self.y_org, self.width, self.height = unpacker.unpack("hhHH")
+        self.x_org, self.y_org, self.width, self.height = unpacker.unpack("=hhHH")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -40,7 +38,6 @@ class ScreenInfo(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -49,16 +46,14 @@ class QueryVersionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.major, self.minor = unpacker.unpack("xx2x4xHH")
+        self.major, self.minor = unpacker.unpack("=xx2x4xHH")
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class GetStateReply(xcffib.Reply):
     xge = False
 
@@ -67,16 +62,14 @@ class GetStateReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.state, self.window = unpacker.unpack("xB2x4xI")
+        self.state, self.window = unpacker.unpack("=xB2x4xI")
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetStateCookie(xcffib.Cookie):
     reply_type = GetStateReply
 
 
-@dataclass(init=False)
 class GetScreenCountReply(xcffib.Reply):
     xge = False
 
@@ -85,16 +78,14 @@ class GetScreenCountReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.screen_count, self.window = unpacker.unpack("xB2x4xI")
+        self.screen_count, self.window = unpacker.unpack("=xB2x4xI")
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetScreenCountCookie(xcffib.Cookie):
     reply_type = GetScreenCountReply
 
 
-@dataclass(init=False)
 class GetScreenSizeReply(xcffib.Reply):
     xge = False
 
@@ -104,17 +95,15 @@ class GetScreenSizeReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.width, self.height, self.window, self.screen = unpacker.unpack(
-            "xx2x4xIIII"
+            "=xx2x4xIIII"
         )
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetScreenSizeCookie(xcffib.Cookie):
     reply_type = GetScreenSizeReply
 
 
-@dataclass(init=False)
 class IsActiveReply(xcffib.Reply):
     xge = False
 
@@ -123,16 +112,14 @@ class IsActiveReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.state,) = unpacker.unpack("xx2x4xI")
+        (self.state,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class IsActiveCookie(xcffib.Cookie):
     reply_type = IsActiveReply
 
 
-@dataclass(init=False)
 class QueryScreensReply(xcffib.Reply):
     xge = False
 
@@ -141,47 +128,81 @@ class QueryScreensReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.number,) = unpacker.unpack("xx2x4xI20x")
+        (self.number,) = unpacker.unpack("=xx2x4xI20x")
         self.screen_info = xcffib.List(unpacker, ScreenInfo, self.number)
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryScreensCookie(xcffib.Cookie):
     reply_type = QueryScreensReply
 
 
-@dataclass(init=False)
 class xineramaExtension(xcffib.Extension):
     def QueryVersion(self, major, minor, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xBB", major, minor))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 
+    def QueryVersionChecked(self, major, minor):
+        return self.QueryVersion(major, minor, is_checked=True)
+
+    def QueryVersionUnchecked(self, major, minor):
+        return self.QueryVersion(major, minor, is_checked=False)
+
     def GetState(self, window, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
         return self.send_request(1, buf, GetStateCookie, is_checked=is_checked)
 
+    def GetStateChecked(self, window):
+        return self.GetState(window, is_checked=True)
+
+    def GetStateUnchecked(self, window):
+        return self.GetState(window, is_checked=False)
+
     def GetScreenCount(self, window, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
         return self.send_request(2, buf, GetScreenCountCookie, is_checked=is_checked)
 
+    def GetScreenCountChecked(self, window):
+        return self.GetScreenCount(window, is_checked=True)
+
+    def GetScreenCountUnchecked(self, window):
+        return self.GetScreenCount(window, is_checked=False)
+
     def GetScreenSize(self, window, screen, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", window, screen))
         return self.send_request(3, buf, GetScreenSizeCookie, is_checked=is_checked)
 
+    def GetScreenSizeChecked(self, window, screen):
+        return self.GetScreenSize(window, screen, is_checked=True)
+
+    def GetScreenSizeUnchecked(self, window, screen):
+        return self.GetScreenSize(window, screen, is_checked=False)
+
     def IsActive(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(4, buf, IsActiveCookie, is_checked=is_checked)
 
+    def IsActiveChecked(self):
+        return self.IsActive(is_checked=True)
+
+    def IsActiveUnchecked(self):
+        return self.IsActive(is_checked=False)
+
     def QueryScreens(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(5, buf, QueryScreensCookie, is_checked=is_checked)
 
+    def QueryScreensChecked(self):
+        return self.QueryScreens(is_checked=True)
+
+    def QueryScreensUnchecked(self):
+        return self.QueryScreens(is_checked=False)
+
 
 xcffib._add_ext(key, xineramaExtension, _events, _errors)
