@@ -402,6 +402,12 @@ class xprintExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2x"))
         return self.send_request(0, buf, PrintQueryVersionCookie, is_checked=is_checked)
 
+    def PrintQueryVersionChecked(self):
+        return self.PrintQueryVersion(is_checked=True)
+
+    def PrintQueryVersionUnchecked(self):
+        return self.PrintQueryVersion(is_checked=False)
+
     def PrintGetPrinterList(
         self, printerNameLen, localeLen, printer_name, locale, is_checked=True
     ):
@@ -418,11 +424,31 @@ class xprintExtension(xcffib.Extension):
             1, buf, PrintGetPrinterListCookie, is_checked=is_checked
         )
 
+    def PrintGetPrinterListChecked(
+        self, printerNameLen, localeLen, printer_name, locale
+    ):
+        return self.PrintGetPrinterList(
+            printerNameLen, localeLen, printer_name, locale, is_checked=True
+        )
+
+    def PrintGetPrinterListUnchecked(
+        self, printerNameLen, localeLen, printer_name, locale
+    ):
+        return self.PrintGetPrinterList(
+            printerNameLen, localeLen, printer_name, locale, is_checked=False
+        )
+
     def PrintRehashPrinterList(self, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(20, buf, is_checked=is_checked)
 
+    def PrintRehashPrinterListChecked(self):
+        return self.PrintRehashPrinterList(is_checked=True)
+
+    def PrintRehashPrinterListUnchecked(self):
+        return self.PrintRehashPrinterList(is_checked=False)
+
     def CreateContext(
         self,
         context_id,
@@ -443,21 +469,53 @@ class xprintExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(locale, "c"))
         return self.send_request(2, buf, is_checked=is_checked)
 
+    def CreateContextChecked(
+        self, context_id, printerNameLen, localeLen, printerName, locale
+    ):
+        return self.CreateContext(
+            context_id, printerNameLen, localeLen, printerName, locale, is_checked=True
+        )
+
+    def CreateContextUnchecked(
+        self, context_id, printerNameLen, localeLen, printerName, locale
+    ):
+        return self.CreateContext(
+            context_id, printerNameLen, localeLen, printerName, locale, is_checked=False
+        )
+
     def PrintSetContext(self, context, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", context))
         return self.send_request(3, buf, is_checked=is_checked)
 
+    def PrintSetContextChecked(self, context):
+        return self.PrintSetContext(context, is_checked=True)
+
+    def PrintSetContextUnchecked(self, context):
+        return self.PrintSetContext(context, is_checked=False)
+
     def PrintGetContext(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(4, buf, PrintGetContextCookie, is_checked=is_checked)
 
+    def PrintGetContextChecked(self):
+        return self.PrintGetContext(is_checked=True)
+
+    def PrintGetContextUnchecked(self):
+        return self.PrintGetContext(is_checked=False)
+
     def PrintDestroyContext(self, context, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", context))
         return self.send_request(5, buf, is_checked=is_checked)
 
+    def PrintDestroyContextChecked(self, context):
+        return self.PrintDestroyContext(context, is_checked=True)
+
+    def PrintDestroyContextUnchecked(self, context):
+        return self.PrintDestroyContext(context, is_checked=False)
+
     def PrintGetScreenOfContext(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
@@ -465,26 +523,56 @@ class xprintExtension(xcffib.Extension):
             6, buf, PrintGetScreenOfContextCookie, is_checked=is_checked
         )
 
+    def PrintGetScreenOfContextChecked(self):
+        return self.PrintGetScreenOfContext(is_checked=True)
+
+    def PrintGetScreenOfContextUnchecked(self):
+        return self.PrintGetScreenOfContext(is_checked=False)
+
     def PrintStartJob(self, output_mode, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB", output_mode))
         return self.send_request(7, buf, is_checked=is_checked)
 
+    def PrintStartJobChecked(self, output_mode):
+        return self.PrintStartJob(output_mode, is_checked=True)
+
+    def PrintStartJobUnchecked(self, output_mode):
+        return self.PrintStartJob(output_mode, is_checked=False)
+
     def PrintEndJob(self, cancel, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB", cancel))
         return self.send_request(8, buf, is_checked=is_checked)
 
+    def PrintEndJobChecked(self, cancel):
+        return self.PrintEndJob(cancel, is_checked=True)
+
+    def PrintEndJobUnchecked(self, cancel):
+        return self.PrintEndJob(cancel, is_checked=False)
+
     def PrintStartDoc(self, driver_mode, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB", driver_mode))
         return self.send_request(9, buf, is_checked=is_checked)
 
+    def PrintStartDocChecked(self, driver_mode):
+        return self.PrintStartDoc(driver_mode, is_checked=True)
+
+    def PrintStartDocUnchecked(self, driver_mode):
+        return self.PrintStartDoc(driver_mode, is_checked=False)
+
     def PrintEndDoc(self, cancel, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB", cancel))
         return self.send_request(10, buf, is_checked=is_checked)
 
+    def PrintEndDocChecked(self, cancel):
+        return self.PrintEndDoc(cancel, is_checked=True)
+
+    def PrintEndDocUnchecked(self, cancel):
+        return self.PrintEndDoc(cancel, is_checked=False)
+
     def PrintPutDocumentData(
         self,
         drawable,
@@ -513,6 +601,34 @@ class xprintExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(options, "c"))
         return self.send_request(11, buf, is_checked=is_checked)
 
+    def PrintPutDocumentDataChecked(
+        self, drawable, len_data, len_fmt, len_options, data, doc_format, options
+    ):
+        return self.PrintPutDocumentData(
+            drawable,
+            len_data,
+            len_fmt,
+            len_options,
+            data,
+            doc_format,
+            options,
+            is_checked=True,
+        )
+
+    def PrintPutDocumentDataUnchecked(
+        self, drawable, len_data, len_fmt, len_options, data, doc_format, options
+    ):
+        return self.PrintPutDocumentData(
+            drawable,
+            len_data,
+            len_fmt,
+            len_options,
+            data,
+            doc_format,
+            options,
+            is_checked=False,
+        )
+
     def PrintGetDocumentData(self, context, max_bytes, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", context, max_bytes))
@@ -520,21 +636,45 @@ class xprintExtension(xcffib.Extension):
             12, buf, PrintGetDocumentDataCookie, is_checked=is_checked
         )
 
+    def PrintGetDocumentDataChecked(self, context, max_bytes):
+        return self.PrintGetDocumentData(context, max_bytes, is_checked=True)
+
+    def PrintGetDocumentDataUnchecked(self, context, max_bytes):
+        return self.PrintGetDocumentData(context, max_bytes, is_checked=False)
+
     def PrintStartPage(self, window, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
         return self.send_request(13, buf, is_checked=is_checked)
 
+    def PrintStartPageChecked(self, window):
+        return self.PrintStartPage(window, is_checked=True)
+
+    def PrintStartPageUnchecked(self, window):
+        return self.PrintStartPage(window, is_checked=False)
+
     def PrintEndPage(self, cancel, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB3x", cancel))
         return self.send_request(14, buf, is_checked=is_checked)
 
+    def PrintEndPageChecked(self, cancel):
+        return self.PrintEndPage(cancel, is_checked=True)
+
+    def PrintEndPageUnchecked(self, cancel):
+        return self.PrintEndPage(cancel, is_checked=False)
+
     def PrintSelectInput(self, context, event_mask, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", context, event_mask))
         return self.send_request(15, buf, is_checked=is_checked)
 
+    def PrintSelectInputChecked(self, context, event_mask):
+        return self.PrintSelectInput(context, event_mask, is_checked=True)
+
+    def PrintSelectInputUnchecked(self, context, event_mask):
+        return self.PrintSelectInput(context, event_mask, is_checked=False)
+
     def PrintInputSelected(self, context, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", context))
@@ -542,6 +682,12 @@ class xprintExtension(xcffib.Extension):
             16, buf, PrintInputSelectedCookie, is_checked=is_checked
         )
 
+    def PrintInputSelectedChecked(self, context):
+        return self.PrintInputSelected(context, is_checked=True)
+
+    def PrintInputSelectedUnchecked(self, context):
+        return self.PrintInputSelected(context, is_checked=False)
+
     def PrintGetAttributes(self, context, pool, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIB3x", context, pool))
@@ -549,6 +695,12 @@ class xprintExtension(xcffib.Extension):
             17, buf, PrintGetAttributesCookie, is_checked=is_checked
         )
 
+    def PrintGetAttributesChecked(self, context, pool):
+        return self.PrintGetAttributes(context, pool, is_checked=True)
+
+    def PrintGetAttributesUnchecked(self, context, pool):
+        return self.PrintGetAttributes(context, pool, is_checked=False)
+
     def PrintGetOneAttributes(self, context, nameLen, pool, name, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIB3x", context, nameLen, pool))
@@ -557,6 +709,14 @@ class xprintExtension(xcffib.Extension):
             19, buf, PrintGetOneAttributesCookie, is_checked=is_checked
         )
 
+    def PrintGetOneAttributesChecked(self, context, nameLen, pool, name):
+        return self.PrintGetOneAttributes(context, nameLen, pool, name, is_checked=True)
+
+    def PrintGetOneAttributesUnchecked(self, context, nameLen, pool, name):
+        return self.PrintGetOneAttributes(
+            context, nameLen, pool, name, is_checked=False
+        )
+
     def PrintSetAttributes(
         self,
         context,
@@ -572,6 +732,20 @@ class xprintExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(attributes, "c"))
         return self.send_request(18, buf, is_checked=is_checked)
 
+    def PrintSetAttributesChecked(
+        self, context, stringLen, pool, rule, attributes_len, attributes
+    ):
+        return self.PrintSetAttributes(
+            context, stringLen, pool, rule, attributes_len, attributes, is_checked=True
+        )
+
+    def PrintSetAttributesUnchecked(
+        self, context, stringLen, pool, rule, attributes_len, attributes
+    ):
+        return self.PrintSetAttributes(
+            context, stringLen, pool, rule, attributes_len, attributes, is_checked=False
+        )
+
     def PrintGetPageDimensions(self, context, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", context))
@@ -579,6 +753,12 @@ class xprintExtension(xcffib.Extension):
             21, buf, PrintGetPageDimensionsCookie, is_checked=is_checked
         )
 
+    def PrintGetPageDimensionsChecked(self, context):
+        return self.PrintGetPageDimensions(context, is_checked=True)
+
+    def PrintGetPageDimensionsUnchecked(self, context):
+        return self.PrintGetPageDimensions(context, is_checked=False)
+
     def PrintQueryScreens(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
@@ -586,6 +766,12 @@ class xprintExtension(xcffib.Extension):
             22, buf, PrintQueryScreensCookie, is_checked=is_checked
         )
 
+    def PrintQueryScreensChecked(self):
+        return self.PrintQueryScreens(is_checked=True)
+
+    def PrintQueryScreensUnchecked(self):
+        return self.PrintQueryScreens(is_checked=False)
+
     def PrintSetImageResolution(self, context, image_resolution, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIH", context, image_resolution))
@@ -593,6 +779,12 @@ class xprintExtension(xcffib.Extension):
             23, buf, PrintSetImageResolutionCookie, is_checked=is_checked
         )
 
+    def PrintSetImageResolutionChecked(self, context, image_resolution):
+        return self.PrintSetImageResolution(context, image_resolution, is_checked=True)
+
+    def PrintSetImageResolutionUnchecked(self, context, image_resolution):
+        return self.PrintSetImageResolution(context, image_resolution, is_checked=False)
+
     def PrintGetImageResolution(self, context, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", context))
@@ -600,5 +792,11 @@ class xprintExtension(xcffib.Extension):
             24, buf, PrintGetImageResolutionCookie, is_checked=is_checked
         )
 
+    def PrintGetImageResolutionChecked(self, context):
+        return self.PrintGetImageResolution(context, is_checked=True)
+
+    def PrintGetImageResolutionUnchecked(self, context):
+        return self.PrintGetImageResolution(context, is_checked=False)
+
 
 xcffib._add_ext(key, xprintExtension, _events, _errors)
