@@ -18,7 +18,7 @@ class QueryVersionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.server_major, self.server_minor = unpacker.unpack("xx2x4xHH")
+        self.server_major, self.server_minor = unpacker.unpack("=xx2x4xHH")
         self.bufsize = unpacker.offset - base
 
 
@@ -34,7 +34,7 @@ class GetDeviceCreateContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_len,) = unpacker.unpack("=xx2x4xI20x")
         self.context = xcffib.List(unpacker, "c", self.context_len)
         self.bufsize = unpacker.offset - base
 
@@ -51,7 +51,7 @@ class GetDeviceContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_len,) = unpacker.unpack("=xx2x4xI20x")
         self.context = xcffib.List(unpacker, "c", self.context_len)
         self.bufsize = unpacker.offset - base
 
@@ -68,7 +68,7 @@ class GetWindowCreateContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_len,) = unpacker.unpack("=xx2x4xI20x")
         self.context = xcffib.List(unpacker, "c", self.context_len)
         self.bufsize = unpacker.offset - base
 
@@ -85,7 +85,7 @@ class GetWindowContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_len,) = unpacker.unpack("=xx2x4xI20x")
         self.context = xcffib.List(unpacker, "c", self.context_len)
         self.bufsize = unpacker.offset - base
 
@@ -103,7 +103,7 @@ class ListItem(xcffib.Struct):
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
         self.name, self.object_context_len, self.data_context_len = unpacker.unpack(
-            "III"
+            "=III"
         )
         self.object_context = xcffib.List(unpacker, "c", self.object_context_len)
         unpacker.pad("c")
@@ -152,7 +152,7 @@ class GetPropertyCreateContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_len,) = unpacker.unpack("=xx2x4xI20x")
         self.context = xcffib.List(unpacker, "c", self.context_len)
         self.bufsize = unpacker.offset - base
 
@@ -169,7 +169,7 @@ class GetPropertyUseContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_len,) = unpacker.unpack("=xx2x4xI20x")
         self.context = xcffib.List(unpacker, "c", self.context_len)
         self.bufsize = unpacker.offset - base
 
@@ -186,7 +186,7 @@ class GetPropertyContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_len,) = unpacker.unpack("=xx2x4xI20x")
         self.context = xcffib.List(unpacker, "c", self.context_len)
         self.bufsize = unpacker.offset - base
 
@@ -203,7 +203,7 @@ class GetPropertyDataContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_len,) = unpacker.unpack("=xx2x4xI20x")
         self.context = xcffib.List(unpacker, "c", self.context_len)
         self.bufsize = unpacker.offset - base
 
@@ -220,7 +220,7 @@ class ListPropertiesReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.properties_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.properties_len,) = unpacker.unpack("=xx2x4xI20x")
         self.properties = xcffib.List(unpacker, ListItem, self.properties_len)
         self.bufsize = unpacker.offset - base
 
@@ -237,7 +237,7 @@ class GetSelectionCreateContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_len,) = unpacker.unpack("=xx2x4xI20x")
         self.context = xcffib.List(unpacker, "c", self.context_len)
         self.bufsize = unpacker.offset - base
 
@@ -254,7 +254,7 @@ class GetSelectionUseContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_len,) = unpacker.unpack("=xx2x4xI20x")
         self.context = xcffib.List(unpacker, "c", self.context_len)
         self.bufsize = unpacker.offset - base
 
@@ -271,7 +271,7 @@ class GetSelectionContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_len,) = unpacker.unpack("=xx2x4xI20x")
         self.context = xcffib.List(unpacker, "c", self.context_len)
         self.bufsize = unpacker.offset - base
 
@@ -288,7 +288,7 @@ class GetSelectionDataContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_len,) = unpacker.unpack("=xx2x4xI20x")
         self.context = xcffib.List(unpacker, "c", self.context_len)
         self.bufsize = unpacker.offset - base
 
@@ -305,7 +305,7 @@ class ListSelectionsReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.selections_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.selections_len,) = unpacker.unpack("=xx2x4xI20x")
         self.selections = xcffib.List(unpacker, ListItem, self.selections_len)
         self.bufsize = unpacker.offset - base
 
@@ -322,7 +322,7 @@ class GetClientContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_len,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_len,) = unpacker.unpack("=xx2x4xI20x")
         self.context = xcffib.List(unpacker, "c", self.context_len)
         self.bufsize = unpacker.offset - base
 
@@ -337,12 +337,24 @@ class xselinuxExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2xBB", client_major, client_minor))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 
+    def QueryVersionChecked(self, client_major, client_minor):
+        return self.QueryVersion(client_major, client_minor, is_checked=True)
+
+    def QueryVersionUnchecked(self, client_major, client_minor):
+        return self.QueryVersion(client_major, client_minor, is_checked=False)
+
     def SetDeviceCreateContext(self, context_len, context, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", context_len))
         buf.write(xcffib.pack_list(context, "c"))
         return self.send_request(1, buf, is_checked=is_checked)
 
+    def SetDeviceCreateContextChecked(self, context_len, context):
+        return self.SetDeviceCreateContext(context_len, context, is_checked=True)
+
+    def SetDeviceCreateContextUnchecked(self, context_len, context):
+        return self.SetDeviceCreateContext(context_len, context, is_checked=False)
+
     def GetDeviceCreateContext(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
@@ -350,23 +362,47 @@ class xselinuxExtension(xcffib.Extension):
             2, buf, GetDeviceCreateContextCookie, is_checked=is_checked
         )
 
+    def GetDeviceCreateContextChecked(self):
+        return self.GetDeviceCreateContext(is_checked=True)
+
+    def GetDeviceCreateContextUnchecked(self):
+        return self.GetDeviceCreateContext(is_checked=False)
+
     def SetDeviceContext(self, device, context_len, context, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", device, context_len))
         buf.write(xcffib.pack_list(context, "c"))
         return self.send_request(3, buf, is_checked=is_checked)
 
+    def SetDeviceContextChecked(self, device, context_len, context):
+        return self.SetDeviceContext(device, context_len, context, is_checked=True)
+
+    def SetDeviceContextUnchecked(self, device, context_len, context):
+        return self.SetDeviceContext(device, context_len, context, is_checked=False)
+
     def GetDeviceContext(self, device, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", device))
         return self.send_request(4, buf, GetDeviceContextCookie, is_checked=is_checked)
 
+    def GetDeviceContextChecked(self, device):
+        return self.GetDeviceContext(device, is_checked=True)
+
+    def GetDeviceContextUnchecked(self, device):
+        return self.GetDeviceContext(device, is_checked=False)
+
     def SetWindowCreateContext(self, context_len, context, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", context_len))
         buf.write(xcffib.pack_list(context, "c"))
         return self.send_request(5, buf, is_checked=is_checked)
 
+    def SetWindowCreateContextChecked(self, context_len, context):
+        return self.SetWindowCreateContext(context_len, context, is_checked=True)
+
+    def SetWindowCreateContextUnchecked(self, context_len, context):
+        return self.SetWindowCreateContext(context_len, context, is_checked=False)
+
     def GetWindowCreateContext(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
@@ -374,17 +410,35 @@ class xselinuxExtension(xcffib.Extension):
             6, buf, GetWindowCreateContextCookie, is_checked=is_checked
         )
 
+    def GetWindowCreateContextChecked(self):
+        return self.GetWindowCreateContext(is_checked=True)
+
+    def GetWindowCreateContextUnchecked(self):
+        return self.GetWindowCreateContext(is_checked=False)
+
     def GetWindowContext(self, window, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
         return self.send_request(7, buf, GetWindowContextCookie, is_checked=is_checked)
 
+    def GetWindowContextChecked(self, window):
+        return self.GetWindowContext(window, is_checked=True)
+
+    def GetWindowContextUnchecked(self, window):
+        return self.GetWindowContext(window, is_checked=False)
+
     def SetPropertyCreateContext(self, context_len, context, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", context_len))
         buf.write(xcffib.pack_list(context, "c"))
         return self.send_request(8, buf, is_checked=is_checked)
 
+    def SetPropertyCreateContextChecked(self, context_len, context):
+        return self.SetPropertyCreateContext(context_len, context, is_checked=True)
+
+    def SetPropertyCreateContextUnchecked(self, context_len, context):
+        return self.SetPropertyCreateContext(context_len, context, is_checked=False)
+
     def GetPropertyCreateContext(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
@@ -392,12 +446,24 @@ class xselinuxExtension(xcffib.Extension):
             9, buf, GetPropertyCreateContextCookie, is_checked=is_checked
         )
 
+    def GetPropertyCreateContextChecked(self):
+        return self.GetPropertyCreateContext(is_checked=True)
+
+    def GetPropertyCreateContextUnchecked(self):
+        return self.GetPropertyCreateContext(is_checked=False)
+
     def SetPropertyUseContext(self, context_len, context, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", context_len))
         buf.write(xcffib.pack_list(context, "c"))
         return self.send_request(10, buf, is_checked=is_checked)
 
+    def SetPropertyUseContextChecked(self, context_len, context):
+        return self.SetPropertyUseContext(context_len, context, is_checked=True)
+
+    def SetPropertyUseContextUnchecked(self, context_len, context):
+        return self.SetPropertyUseContext(context_len, context, is_checked=False)
+
     def GetPropertyUseContext(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
@@ -405,6 +471,12 @@ class xselinuxExtension(xcffib.Extension):
             11, buf, GetPropertyUseContextCookie, is_checked=is_checked
         )
 
+    def GetPropertyUseContextChecked(self):
+        return self.GetPropertyUseContext(is_checked=True)
+
+    def GetPropertyUseContextUnchecked(self):
+        return self.GetPropertyUseContext(is_checked=False)
+
     def GetPropertyContext(self, window, property, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", window, property))
@@ -412,6 +484,12 @@ class xselinuxExtension(xcffib.Extension):
             12, buf, GetPropertyContextCookie, is_checked=is_checked
         )
 
+    def GetPropertyContextChecked(self, window, property):
+        return self.GetPropertyContext(window, property, is_checked=True)
+
+    def GetPropertyContextUnchecked(self, window, property):
+        return self.GetPropertyContext(window, property, is_checked=False)
+
     def GetPropertyDataContext(self, window, property, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", window, property))
@@ -419,17 +497,35 @@ class xselinuxExtension(xcffib.Extension):
             13, buf, GetPropertyDataContextCookie, is_checked=is_checked
         )
 
+    def GetPropertyDataContextChecked(self, window, property):
+        return self.GetPropertyDataContext(window, property, is_checked=True)
+
+    def GetPropertyDataContextUnchecked(self, window, property):
+        return self.GetPropertyDataContext(window, property, is_checked=False)
+
     def ListProperties(self, window, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
         return self.send_request(14, buf, ListPropertiesCookie, is_checked=is_checked)
 
+    def ListPropertiesChecked(self, window):
+        return self.ListProperties(window, is_checked=True)
+
+    def ListPropertiesUnchecked(self, window):
+        return self.ListProperties(window, is_checked=False)
+
     def SetSelectionCreateContext(self, context_len, context, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", context_len))
         buf.write(xcffib.pack_list(context, "c"))
         return self.send_request(15, buf, is_checked=is_checked)
 
+    def SetSelectionCreateContextChecked(self, context_len, context):
+        return self.SetSelectionCreateContext(context_len, context, is_checked=True)
+
+    def SetSelectionCreateContextUnchecked(self, context_len, context):
+        return self.SetSelectionCreateContext(context_len, context, is_checked=False)
+
     def GetSelectionCreateContext(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
@@ -437,12 +533,24 @@ class xselinuxExtension(xcffib.Extension):
             16, buf, GetSelectionCreateContextCookie, is_checked=is_checked
         )
 
+    def GetSelectionCreateContextChecked(self):
+        return self.GetSelectionCreateContext(is_checked=True)
+
+    def GetSelectionCreateContextUnchecked(self):
+        return self.GetSelectionCreateContext(is_checked=False)
+
     def SetSelectionUseContext(self, context_len, context, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", context_len))
         buf.write(xcffib.pack_list(context, "c"))
         return self.send_request(17, buf, is_checked=is_checked)
 
+    def SetSelectionUseContextChecked(self, context_len, context):
+        return self.SetSelectionUseContext(context_len, context, is_checked=True)
+
+    def SetSelectionUseContextUnchecked(self, context_len, context):
+        return self.SetSelectionUseContext(context_len, context, is_checked=False)
+
     def GetSelectionUseContext(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
@@ -450,6 +558,12 @@ class xselinuxExtension(xcffib.Extension):
             18, buf, GetSelectionUseContextCookie, is_checked=is_checked
         )
 
+    def GetSelectionUseContextChecked(self):
+        return self.GetSelectionUseContext(is_checked=True)
+
+    def GetSelectionUseContextUnchecked(self):
+        return self.GetSelectionUseContext(is_checked=False)
+
     def GetSelectionContext(self, selection, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", selection))
@@ -457,6 +571,12 @@ class xselinuxExtension(xcffib.Extension):
             19, buf, GetSelectionContextCookie, is_checked=is_checked
         )
 
+    def GetSelectionContextChecked(self, selection):
+        return self.GetSelectionContext(selection, is_checked=True)
+
+    def GetSelectionContextUnchecked(self, selection):
+        return self.GetSelectionContext(selection, is_checked=False)
+
     def GetSelectionDataContext(self, selection, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", selection))
@@ -464,15 +584,33 @@ class xselinuxExtension(xcffib.Extension):
             20, buf, GetSelectionDataContextCookie, is_checked=is_checked
         )
 
+    def GetSelectionDataContextChecked(self, selection):
+        return self.GetSelectionDataContext(selection, is_checked=True)
+
+    def GetSelectionDataContextUnchecked(self, selection):
+        return self.GetSelectionDataContext(selection, is_checked=False)
+
     def ListSelections(self, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(21, buf, ListSelectionsCookie, is_checked=is_checked)
 
+    def ListSelectionsChecked(self):
+        return self.ListSelections(is_checked=True)
+
+    def ListSelectionsUnchecked(self):
+        return self.ListSelections(is_checked=False)
+
     def GetClientContext(self, resource, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", resource))
         return self.send_request(22, buf, GetClientContextCookie, is_checked=is_checked)
 
+    def GetClientContextChecked(self, resource):
+        return self.GetClientContext(resource, is_checked=True)
+
+    def GetClientContextUnchecked(self, resource):
+        return self.GetClientContext(resource, is_checked=False)
+
 
 xcffib._add_ext(key, xselinuxExtension, _events, _errors)
