@@ -717,26 +717,56 @@ class xvExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2x"))
         return self.send_request(0, buf, QueryExtensionCookie, is_checked=is_checked)
 
+    def QueryExtensionChecked(self):
+        return self.QueryExtension(is_checked=True)
+
+    def QueryExtensionUnchecked(self):
+        return self.QueryExtension(is_checked=False)
+
     def QueryAdaptors(self, window, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
         return self.send_request(1, buf, QueryAdaptorsCookie, is_checked=is_checked)
 
+    def QueryAdaptorsChecked(self, window):
+        return self.QueryAdaptors(window, is_checked=True)
+
+    def QueryAdaptorsUnchecked(self, window):
+        return self.QueryAdaptors(window, is_checked=False)
+
     def QueryEncodings(self, port, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", port))
         return self.send_request(2, buf, QueryEncodingsCookie, is_checked=is_checked)
 
+    def QueryEncodingsChecked(self, port):
+        return self.QueryEncodings(port, is_checked=True)
+
+    def QueryEncodingsUnchecked(self, port):
+        return self.QueryEncodings(port, is_checked=False)
+
     def GrabPort(self, port, time, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", port, time))
         return self.send_request(3, buf, GrabPortCookie, is_checked=is_checked)
 
+    def GrabPortChecked(self, port, time):
+        return self.GrabPort(port, time, is_checked=True)
+
+    def GrabPortUnchecked(self, port, time):
+        return self.GrabPort(port, time, is_checked=False)
+
     def UngrabPort(self, port, time, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", port, time))
         return self.send_request(4, buf, is_checked=is_checked)
 
+    def UngrabPortChecked(self, port, time):
+        return self.UngrabPort(port, time, is_checked=True)
+
+    def UngrabPortUnchecked(self, port, time):
+        return self.UngrabPort(port, time, is_checked=False)
+
     def PutVideo(
         self,
         port,
@@ -771,6 +801,42 @@ class xvExtension(xcffib.Extension):
         )
         return self.send_request(5, buf, is_checked=is_checked)
 
+    def PutVideoChecked(
+        self, port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h
+    ):
+        return self.PutVideo(
+            port,
+            drawable,
+            gc,
+            vid_x,
+            vid_y,
+            vid_w,
+            vid_h,
+            drw_x,
+            drw_y,
+            drw_w,
+            drw_h,
+            is_checked=True,
+        )
+
+    def PutVideoUnchecked(
+        self, port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h
+    ):
+        return self.PutVideo(
+            port,
+            drawable,
+            gc,
+            vid_x,
+            vid_y,
+            vid_w,
+            vid_h,
+            drw_x,
+            drw_y,
+            drw_w,
+            drw_h,
+            is_checked=False,
+        )
+
     def PutStill(
         self,
         port,
@@ -805,6 +871,42 @@ class xvExtension(xcffib.Extension):
         )
         return self.send_request(6, buf, is_checked=is_checked)
 
+    def PutStillChecked(
+        self, port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h
+    ):
+        return self.PutStill(
+            port,
+            drawable,
+            gc,
+            vid_x,
+            vid_y,
+            vid_w,
+            vid_h,
+            drw_x,
+            drw_y,
+            drw_w,
+            drw_h,
+            is_checked=True,
+        )
+
+    def PutStillUnchecked(
+        self, port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h
+    ):
+        return self.PutStill(
+            port,
+            drawable,
+            gc,
+            vid_x,
+            vid_y,
+            vid_w,
+            vid_h,
+            drw_x,
+            drw_y,
+            drw_w,
+            drw_h,
+            is_checked=False,
+        )
+
     def GetVideo(
         self,
         port,
@@ -839,6 +941,42 @@ class xvExtension(xcffib.Extension):
         )
         return self.send_request(7, buf, is_checked=is_checked)
 
+    def GetVideoChecked(
+        self, port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h
+    ):
+        return self.GetVideo(
+            port,
+            drawable,
+            gc,
+            vid_x,
+            vid_y,
+            vid_w,
+            vid_h,
+            drw_x,
+            drw_y,
+            drw_w,
+            drw_h,
+            is_checked=True,
+        )
+
+    def GetVideoUnchecked(
+        self, port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h
+    ):
+        return self.GetVideo(
+            port,
+            drawable,
+            gc,
+            vid_x,
+            vid_y,
+            vid_w,
+            vid_h,
+            drw_x,
+            drw_y,
+            drw_w,
+            drw_h,
+            is_checked=False,
+        )
+
     def GetStill(
         self,
         port,
@@ -873,21 +1011,75 @@ class xvExtension(xcffib.Extension):
         )
         return self.send_request(8, buf, is_checked=is_checked)
 
+    def GetStillChecked(
+        self, port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h
+    ):
+        return self.GetStill(
+            port,
+            drawable,
+            gc,
+            vid_x,
+            vid_y,
+            vid_w,
+            vid_h,
+            drw_x,
+            drw_y,
+            drw_w,
+            drw_h,
+            is_checked=True,
+        )
+
+    def GetStillUnchecked(
+        self, port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h
+    ):
+        return self.GetStill(
+            port,
+            drawable,
+            gc,
+            vid_x,
+            vid_y,
+            vid_w,
+            vid_h,
+            drw_x,
+            drw_y,
+            drw_w,
+            drw_h,
+            is_checked=False,
+        )
+
     def StopVideo(self, port, drawable, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", port, drawable))
         return self.send_request(9, buf, is_checked=is_checked)
 
+    def StopVideoChecked(self, port, drawable):
+        return self.StopVideo(port, drawable, is_checked=True)
+
+    def StopVideoUnchecked(self, port, drawable):
+        return self.StopVideo(port, drawable, is_checked=False)
+
     def SelectVideoNotify(self, drawable, onoff, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIB3x", drawable, onoff))
         return self.send_request(10, buf, is_checked=is_checked)
 
+    def SelectVideoNotifyChecked(self, drawable, onoff):
+        return self.SelectVideoNotify(drawable, onoff, is_checked=True)
+
+    def SelectVideoNotifyUnchecked(self, drawable, onoff):
+        return self.SelectVideoNotify(drawable, onoff, is_checked=False)
+
     def SelectPortNotify(self, port, onoff, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIB3x", port, onoff))
         return self.send_request(11, buf, is_checked=is_checked)
 
+    def SelectPortNotifyChecked(self, port, onoff):
+        return self.SelectPortNotify(port, onoff, is_checked=True)
+
+    def SelectPortNotifyUnchecked(self, port, onoff):
+        return self.SelectPortNotify(port, onoff, is_checked=False)
+
     def QueryBestSize(self, port, vid_w, vid_h, drw_w, drw_h, motion, is_checked=True):
         buf = io.BytesIO()
         buf.write(
@@ -895,16 +1087,38 @@ class xvExtension(xcffib.Extension):
         )
         return self.send_request(12, buf, QueryBestSizeCookie, is_checked=is_checked)
 
+    def QueryBestSizeChecked(self, port, vid_w, vid_h, drw_w, drw_h, motion):
+        return self.QueryBestSize(
+            port, vid_w, vid_h, drw_w, drw_h, motion, is_checked=True
+        )
+
+    def QueryBestSizeUnchecked(self, port, vid_w, vid_h, drw_w, drw_h, motion):
+        return self.QueryBestSize(
+            port, vid_w, vid_h, drw_w, drw_h, motion, is_checked=False
+        )
+
     def SetPortAttribute(self, port, attribute, value, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIi", port, attribute, value))
         return self.send_request(13, buf, is_checked=is_checked)
 
+    def SetPortAttributeChecked(self, port, attribute, value):
+        return self.SetPortAttribute(port, attribute, value, is_checked=True)
+
+    def SetPortAttributeUnchecked(self, port, attribute, value):
+        return self.SetPortAttribute(port, attribute, value, is_checked=False)
+
     def GetPortAttribute(self, port, attribute, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", port, attribute))
         return self.send_request(14, buf, GetPortAttributeCookie, is_checked=is_checked)
 
+    def GetPortAttributeChecked(self, port, attribute):
+        return self.GetPortAttribute(port, attribute, is_checked=True)
+
+    def GetPortAttributeUnchecked(self, port, attribute):
+        return self.GetPortAttribute(port, attribute, is_checked=False)
+
     def QueryPortAttributes(self, port, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", port))
@@ -912,11 +1126,23 @@ class xvExtension(xcffib.Extension):
             15, buf, QueryPortAttributesCookie, is_checked=is_checked
         )
 
+    def QueryPortAttributesChecked(self, port):
+        return self.QueryPortAttributes(port, is_checked=True)
+
+    def QueryPortAttributesUnchecked(self, port):
+        return self.QueryPortAttributes(port, is_checked=False)
+
     def ListImageFormats(self, port, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", port))
         return self.send_request(16, buf, ListImageFormatsCookie, is_checked=is_checked)
 
+    def ListImageFormatsChecked(self, port):
+        return self.ListImageFormats(port, is_checked=True)
+
+    def ListImageFormatsUnchecked(self, port):
+        return self.ListImageFormats(port, is_checked=False)
+
     def QueryImageAttributes(self, port, id, width, height, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIHH", port, id, width, height))
@@ -924,6 +1150,12 @@ class xvExtension(xcffib.Extension):
             17, buf, QueryImageAttributesCookie, is_checked=is_checked
         )
 
+    def QueryImageAttributesChecked(self, port, id, width, height):
+        return self.QueryImageAttributes(port, id, width, height, is_checked=True)
+
+    def QueryImageAttributesUnchecked(self, port, id, width, height):
+        return self.QueryImageAttributes(port, id, width, height, is_checked=False)
+
     def PutImage(
         self,
         port,
@@ -967,6 +1199,84 @@ class xvExtension(xcffib.Extension):
         buf.write(xcffib.pack_list(data, "B"))
         return self.send_request(18, buf, is_checked=is_checked)
 
+    def PutImageChecked(
+        self,
+        port,
+        drawable,
+        gc,
+        id,
+        src_x,
+        src_y,
+        src_w,
+        src_h,
+        drw_x,
+        drw_y,
+        drw_w,
+        drw_h,
+        width,
+        height,
+        data_len,
+        data,
+    ):
+        return self.PutImage(
+            port,
+            drawable,
+            gc,
+            id,
+            src_x,
+            src_y,
+            src_w,
+            src_h,
+            drw_x,
+            drw_y,
+            drw_w,
+            drw_h,
+            width,
+            height,
+            data_len,
+            data,
+            is_checked=True,
+        )
+
+    def PutImageUnchecked(
+        self,
+        port,
+        drawable,
+        gc,
+        id,
+        src_x,
+        src_y,
+        src_w,
+        src_h,
+        drw_x,
+        drw_y,
+        drw_w,
+        drw_h,
+        width,
+        height,
+        data_len,
+        data,
+    ):
+        return self.PutImage(
+            port,
+            drawable,
+            gc,
+            id,
+            src_x,
+            src_y,
+            src_w,
+            src_h,
+            drw_x,
+            drw_y,
+            drw_w,
+            drw_h,
+            width,
+            height,
+            data_len,
+            data,
+            is_checked=False,
+        )
+
     def ShmPutImage(
         self,
         port,
@@ -1013,5 +1323,87 @@ class xvExtension(xcffib.Extension):
         )
         return self.send_request(19, buf, is_checked=is_checked)
 
+    def ShmPutImageChecked(
+        self,
+        port,
+        drawable,
+        gc,
+        shmseg,
+        id,
+        offset,
+        src_x,
+        src_y,
+        src_w,
+        src_h,
+        drw_x,
+        drw_y,
+        drw_w,
+        drw_h,
+        width,
+        height,
+        send_event,
+    ):
+        return self.ShmPutImage(
+            port,
+            drawable,
+            gc,
+            shmseg,
+            id,
+            offset,
+            src_x,
+            src_y,
+            src_w,
+            src_h,
+            drw_x,
+            drw_y,
+            drw_w,
+            drw_h,
+            width,
+            height,
+            send_event,
+            is_checked=True,
+        )
+
+    def ShmPutImageUnchecked(
+        self,
+        port,
+        drawable,
+        gc,
+        shmseg,
+        id,
+        offset,
+        src_x,
+        src_y,
+        src_w,
+        src_h,
+        drw_x,
+        drw_y,
+        drw_w,
+        drw_h,
+        width,
+        height,
+        send_event,
+    ):
+        return self.ShmPutImage(
+            port,
+            drawable,
+            gc,
+            shmseg,
+            id,
+            offset,
+            src_x,
+            src_y,
+            src_w,
+            src_h,
+            drw_x,
+            drw_y,
+            drw_w,
+            drw_h,
+            width,
+            height,
+            send_event,
+            is_checked=False,
+        )
+
 
 xcffib._add_ext(key, xvExtension, _events, _errors)
