@@ -194,11 +194,23 @@ class xvmcExtension(xcffib.Extension):
         buf.write(struct.pack("=xx2x"))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 
+    def QueryVersionChecked(self):
+        return self.QueryVersion(is_checked=True)
+
+    def QueryVersionUnchecked(self):
+        return self.QueryVersion(is_checked=False)
+
     def ListSurfaceTypes(self, port_id, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", port_id))
         return self.send_request(1, buf, ListSurfaceTypesCookie, is_checked=is_checked)
 
+    def ListSurfaceTypesChecked(self, port_id):
+        return self.ListSurfaceTypes(port_id, is_checked=True)
+
+    def ListSurfaceTypesUnchecked(self, port_id):
+        return self.ListSurfaceTypes(port_id, is_checked=False)
+
     def CreateContext(
         self, context_id, port_id, surface_id, width, height, flags, is_checked=True
     ):
@@ -210,21 +222,53 @@ class xvmcExtension(xcffib.Extension):
         )
         return self.send_request(2, buf, CreateContextCookie, is_checked=is_checked)
 
+    def CreateContextChecked(
+        self, context_id, port_id, surface_id, width, height, flags
+    ):
+        return self.CreateContext(
+            context_id, port_id, surface_id, width, height, flags, is_checked=True
+        )
+
+    def CreateContextUnchecked(
+        self, context_id, port_id, surface_id, width, height, flags
+    ):
+        return self.CreateContext(
+            context_id, port_id, surface_id, width, height, flags, is_checked=False
+        )
+
     def DestroyContext(self, context_id, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", context_id))
         return self.send_request(3, buf, is_checked=is_checked)
 
+    def DestroyContextChecked(self, context_id):
+        return self.DestroyContext(context_id, is_checked=True)
+
+    def DestroyContextUnchecked(self, context_id):
+        return self.DestroyContext(context_id, is_checked=False)
+
     def CreateSurface(self, surface_id, context_id, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", surface_id, context_id))
         return self.send_request(4, buf, CreateSurfaceCookie, is_checked=is_checked)
 
+    def CreateSurfaceChecked(self, surface_id, context_id):
+        return self.CreateSurface(surface_id, context_id, is_checked=True)
+
+    def CreateSurfaceUnchecked(self, surface_id, context_id):
+        return self.CreateSurface(surface_id, context_id, is_checked=False)
+
     def DestroySurface(self, surface_id, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", surface_id))
         return self.send_request(5, buf, is_checked=is_checked)
 
+    def DestroySurfaceChecked(self, surface_id):
+        return self.DestroySurface(surface_id, is_checked=True)
+
+    def DestroySurfaceUnchecked(self, surface_id):
+        return self.DestroySurface(surface_id, is_checked=False)
+
     def CreateSubpicture(
         self, subpicture_id, context, xvimage_id, width, height, is_checked=True
     ):
@@ -234,11 +278,31 @@ class xvmcExtension(xcffib.Extension):
         )
         return self.send_request(6, buf, CreateSubpictureCookie, is_checked=is_checked)
 
+    def CreateSubpictureChecked(
+        self, subpicture_id, context, xvimage_id, width, height
+    ):
+        return self.CreateSubpicture(
+            subpicture_id, context, xvimage_id, width, height, is_checked=True
+        )
+
+    def CreateSubpictureUnchecked(
+        self, subpicture_id, context, xvimage_id, width, height
+    ):
+        return self.CreateSubpicture(
+            subpicture_id, context, xvimage_id, width, height, is_checked=False
+        )
+
     def DestroySubpicture(self, subpicture_id, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", subpicture_id))
         return self.send_request(7, buf, is_checked=is_checked)
 
+    def DestroySubpictureChecked(self, subpicture_id):
+        return self.DestroySubpicture(subpicture_id, is_checked=True)
+
+    def DestroySubpictureUnchecked(self, subpicture_id):
+        return self.DestroySubpicture(subpicture_id, is_checked=False)
+
     def ListSubpictureTypes(self, port_id, surface_id, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", port_id, surface_id))
@@ -246,5 +310,11 @@ class xvmcExtension(xcffib.Extension):
             8, buf, ListSubpictureTypesCookie, is_checked=is_checked
         )
 
+    def ListSubpictureTypesChecked(self, port_id, surface_id):
+        return self.ListSubpictureTypes(port_id, surface_id, is_checked=True)
+
+    def ListSubpictureTypesUnchecked(self, port_id, surface_id):
+        return self.ListSubpictureTypes(port_id, surface_id, is_checked=False)
+
 
 xcffib._add_ext(key, xvmcExtension, _events, _errors)
